# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateExtract(object):
    """
    Note: Deprecated. Use the new resource model APIs instead.
    Parameters for Extract processes.
    If an empty object is specified, the stored Extract details will be removed.
    """

    #: A constant which can be used with the performance_profile property of a UpdateExtract.
    #: This constant has a value of "LOW"
    PERFORMANCE_PROFILE_LOW = "LOW"

    #: A constant which can be used with the performance_profile property of a UpdateExtract.
    #: This constant has a value of "MEDIUM"
    PERFORMANCE_PROFILE_MEDIUM = "MEDIUM"

    #: A constant which can be used with the performance_profile property of a UpdateExtract.
    #: This constant has a value of "HIGH"
    PERFORMANCE_PROFILE_HIGH = "HIGH"

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateExtract object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param performance_profile:
            The value to assign to the performance_profile property of this UpdateExtract.
            Allowed values for this property are: "LOW", "MEDIUM", "HIGH"
        :type performance_profile: str

        :param long_trans_duration:
            The value to assign to the long_trans_duration property of this UpdateExtract.
        :type long_trans_duration: int

        """
        self.swagger_types = {
            'performance_profile': 'str',
            'long_trans_duration': 'int'
        }

        self.attribute_map = {
            'performance_profile': 'performanceProfile',
            'long_trans_duration': 'longTransDuration'
        }

        self._performance_profile = None
        self._long_trans_duration = None

    @property
    def performance_profile(self):
        """
        Gets the performance_profile of this UpdateExtract.
        Extract performance.

        Allowed values for this property are: "LOW", "MEDIUM", "HIGH"


        :return: The performance_profile of this UpdateExtract.
        :rtype: str
        """
        return self._performance_profile

    @performance_profile.setter
    def performance_profile(self, performance_profile):
        """
        Sets the performance_profile of this UpdateExtract.
        Extract performance.


        :param performance_profile: The performance_profile of this UpdateExtract.
        :type: str
        """
        allowed_values = ["LOW", "MEDIUM", "HIGH"]
        if not value_allowed_none_or_none_sentinel(performance_profile, allowed_values):
            raise ValueError(
                "Invalid value for `performance_profile`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._performance_profile = performance_profile

    @property
    def long_trans_duration(self):
        """
        Gets the long_trans_duration of this UpdateExtract.
        Length of time (in seconds) that a transaction can be open before Extract generates a warning message that the transaction is long-running.
        If not specified, Extract will not generate a warning on long-running transactions.


        :return: The long_trans_duration of this UpdateExtract.
        :rtype: int
        """
        return self._long_trans_duration

    @long_trans_duration.setter
    def long_trans_duration(self, long_trans_duration):
        """
        Sets the long_trans_duration of this UpdateExtract.
        Length of time (in seconds) that a transaction can be open before Extract generates a warning message that the transaction is long-running.
        If not specified, Extract will not generate a warning on long-running transactions.


        :param long_trans_duration: The long_trans_duration of this UpdateExtract.
        :type: int
        """
        self._long_trans_duration = long_trans_duration

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .rule_condition import RuleCondition
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SourceVcnIpAddressCondition(RuleCondition):
    """
    An access control rule condition that requires a match on the specified source VCN and IP address range.
    This condition must be used only in conjunction with `SourceVcnIdCondition`.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SourceVcnIpAddressCondition object with values from keyword arguments. The default value of the :py:attr:`~oci.load_balancer.models.SourceVcnIpAddressCondition.attribute_name` attribute
        of this class is ``SOURCE_VCN_IP_ADDRESS`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param attribute_name:
            The value to assign to the attribute_name property of this SourceVcnIpAddressCondition.
            Allowed values for this property are: "SOURCE_IP_ADDRESS", "SOURCE_VCN_ID", "SOURCE_VCN_IP_ADDRESS", "PATH"
        :type attribute_name: str

        :param attribute_value:
            The value to assign to the attribute_value property of this SourceVcnIpAddressCondition.
        :type attribute_value: str

        """
        self.swagger_types = {
            'attribute_name': 'str',
            'attribute_value': 'str'
        }

        self.attribute_map = {
            'attribute_name': 'attributeName',
            'attribute_value': 'attributeValue'
        }

        self._attribute_name = None
        self._attribute_value = None
        self._attribute_name = 'SOURCE_VCN_IP_ADDRESS'

    @property
    def attribute_value(self):
        """
        **[Required]** Gets the attribute_value of this SourceVcnIpAddressCondition.
        An IPv4 address range that the original client IP address (in the context of the specified VCN) of an
        incoming packet must match.

        The service accepts only classless inter-domain routing (CIDR) format (x.x.x.x/y) strings.

        Specify 0.0.0.0/0 to match all incoming traffic in the customer VCN.

        example: \"10.10.1.0/24\"


        :return: The attribute_value of this SourceVcnIpAddressCondition.
        :rtype: str
        """
        return self._attribute_value

    @attribute_value.setter
    def attribute_value(self, attribute_value):
        """
        Sets the attribute_value of this SourceVcnIpAddressCondition.
        An IPv4 address range that the original client IP address (in the context of the specified VCN) of an
        incoming packet must match.

        The service accepts only classless inter-domain routing (CIDR) format (x.x.x.x/y) strings.

        Specify 0.0.0.0/0 to match all incoming traffic in the customer VCN.

        example: \"10.10.1.0/24\"


        :param attribute_value: The attribute_value of this SourceVcnIpAddressCondition.
        :type: str
        """
        self._attribute_value = attribute_value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .browser_monitor_configuration import BrowserMonitorConfiguration
from .create_monitor_details import CreateMonitorDetails
from .create_script_details import CreateScriptDetails
from .geo_summary import GeoSummary
from .header import Header
from .monitor import Monitor
from .monitor_collection import MonitorCollection
from .monitor_configuration import MonitorConfiguration
from .monitor_result import MonitorResult
from .monitor_result_data import MonitorResultData
from .monitor_script_parameter import MonitorScriptParameter
from .monitor_script_parameter_info import MonitorScriptParameterInfo
from .monitor_status_count_map import MonitorStatusCountMap
from .monitor_summary import MonitorSummary
from .public_vantage_point_collection import PublicVantagePointCollection
from .public_vantage_point_summary import PublicVantagePointSummary
from .request_authentication_details import RequestAuthenticationDetails
from .request_query_param import RequestQueryParam
from .rest_monitor_configuration import RestMonitorConfiguration
from .script import Script
from .script_collection import ScriptCollection
from .script_parameter import ScriptParameter
from .script_parameter_info import ScriptParameterInfo
from .script_summary import ScriptSummary
from .scripted_browser_monitor_configuration import ScriptedBrowserMonitorConfiguration
from .scripted_rest_monitor_configuration import ScriptedRestMonitorConfiguration
from .update_monitor_details import UpdateMonitorDetails
from .update_script_details import UpdateScriptDetails
from .vantage_point_info import VantagePointInfo
from .verify_text import VerifyText

# Maps type names to classes for apm_synthetics services.
apm_synthetics_type_mapping = {
    "BrowserMonitorConfiguration": BrowserMonitorConfiguration,
    "CreateMonitorDetails": CreateMonitorDetails,
    "CreateScriptDetails": CreateScriptDetails,
    "GeoSummary": GeoSummary,
    "Header": Header,
    "Monitor": Monitor,
    "MonitorCollection": MonitorCollection,
    "MonitorConfiguration": MonitorConfiguration,
    "MonitorResult": MonitorResult,
    "MonitorResultData": MonitorResultData,
    "MonitorScriptParameter": MonitorScriptParameter,
    "MonitorScriptParameterInfo": MonitorScriptParameterInfo,
    "MonitorStatusCountMap": MonitorStatusCountMap,
    "MonitorSummary": MonitorSummary,
    "PublicVantagePointCollection": PublicVantagePointCollection,
    "PublicVantagePointSummary": PublicVantagePointSummary,
    "RequestAuthenticationDetails": RequestAuthenticationDetails,
    "RequestQueryParam": RequestQueryParam,
    "RestMonitorConfiguration": RestMonitorConfiguration,
    "Script": Script,
    "ScriptCollection": ScriptCollection,
    "ScriptParameter": ScriptParameter,
    "ScriptParameterInfo": ScriptParameterInfo,
    "ScriptSummary": ScriptSummary,
    "ScriptedBrowserMonitorConfiguration": ScriptedBrowserMonitorConfiguration,
    "ScriptedRestMonitorConfiguration": ScriptedRestMonitorConfiguration,
    "UpdateMonitorDetails": UpdateMonitorDetails,
    "UpdateScriptDetails": UpdateScriptDetails,
    "VantagePointInfo": VantagePointInfo,
    "VerifyText": VerifyText
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .network_endpoint_details import NetworkEndpointDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PublicEndpointDetails(NetworkEndpointDetails):
    """
    Public endpoint configuration details.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PublicEndpointDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.analytics.models.PublicEndpointDetails.network_endpoint_type` attribute
        of this class is ``PUBLIC`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param network_endpoint_type:
            The value to assign to the network_endpoint_type property of this PublicEndpointDetails.
            Allowed values for this property are: "PUBLIC", "PRIVATE"
        :type network_endpoint_type: str

        :param whitelisted_ips:
            The value to assign to the whitelisted_ips property of this PublicEndpointDetails.
        :type whitelisted_ips: list[str]

        :param whitelisted_vcns:
            The value to assign to the whitelisted_vcns property of this PublicEndpointDetails.
        :type whitelisted_vcns: list[oci.analytics.models.VirtualCloudNetwork]

        """
        self.swagger_types = {
            'network_endpoint_type': 'str',
            'whitelisted_ips': 'list[str]',
            'whitelisted_vcns': 'list[VirtualCloudNetwork]'
        }

        self.attribute_map = {
            'network_endpoint_type': 'networkEndpointType',
            'whitelisted_ips': 'whitelistedIps',
            'whitelisted_vcns': 'whitelistedVcns'
        }

        self._network_endpoint_type = None
        self._whitelisted_ips = None
        self._whitelisted_vcns = None
        self._network_endpoint_type = 'PUBLIC'

    @property
    def whitelisted_ips(self):
        """
        Gets the whitelisted_ips of this PublicEndpointDetails.
        Source IP addresses or IP address ranges igress rules.


        :return: The whitelisted_ips of this PublicEndpointDetails.
        :rtype: list[str]
        """
        return self._whitelisted_ips

    @whitelisted_ips.setter
    def whitelisted_ips(self, whitelisted_ips):
        """
        Sets the whitelisted_ips of this PublicEndpointDetails.
        Source IP addresses or IP address ranges igress rules.


        :param whitelisted_ips: The whitelisted_ips of this PublicEndpointDetails.
        :type: list[str]
        """
        self._whitelisted_ips = whitelisted_ips

    @property
    def whitelisted_vcns(self):
        """
        Gets the whitelisted_vcns of this PublicEndpointDetails.
        Virtual Cloud Networks allowed to access this network endpoint.


        :return: The whitelisted_vcns of this PublicEndpointDetails.
        :rtype: list[oci.analytics.models.VirtualCloudNetwork]
        """
        return self._whitelisted_vcns

    @whitelisted_vcns.setter
    def whitelisted_vcns(self, whitelisted_vcns):
        """
        Sets the whitelisted_vcns of this PublicEndpointDetails.
        Virtual Cloud Networks allowed to access this network endpoint.


        :param whitelisted_vcns: The whitelisted_vcns of this PublicEndpointDetails.
        :type: list[oci.analytics.models.VirtualCloudNetwork]
        """
        self._whitelisted_vcns = whitelisted_vcns

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SignedData(object):
    """
    SignedData model.
    """

    #: A constant which can be used with the signing_algorithm property of a SignedData.
    #: This constant has a value of "SHA_224_RSA_PKCS_PSS"
    SIGNING_ALGORITHM_SHA_224_RSA_PKCS_PSS = "SHA_224_RSA_PKCS_PSS"

    #: A constant which can be used with the signing_algorithm property of a SignedData.
    #: This constant has a value of "SHA_256_RSA_PKCS_PSS"
    SIGNING_ALGORITHM_SHA_256_RSA_PKCS_PSS = "SHA_256_RSA_PKCS_PSS"

    #: A constant which can be used with the signing_algorithm property of a SignedData.
    #: This constant has a value of "SHA_384_RSA_PKCS_PSS"
    SIGNING_ALGORITHM_SHA_384_RSA_PKCS_PSS = "SHA_384_RSA_PKCS_PSS"

    #: A constant which can be used with the signing_algorithm property of a SignedData.
    #: This constant has a value of "SHA_512_RSA_PKCS_PSS"
    SIGNING_ALGORITHM_SHA_512_RSA_PKCS_PSS = "SHA_512_RSA_PKCS_PSS"

    #: A constant which can be used with the signing_algorithm property of a SignedData.
    #: This constant has a value of "SHA_224_RSA_PKCS1_V1_5"
    SIGNING_ALGORITHM_SHA_224_RSA_PKCS1_V1_5 = "SHA_224_RSA_PKCS1_V1_5"

    #: A constant which can be used with the signing_algorithm property of a SignedData.
    #: This constant has a value of "SHA_256_RSA_PKCS1_V1_5"
    SIGNING_ALGORITHM_SHA_256_RSA_PKCS1_V1_5 = "SHA_256_RSA_PKCS1_V1_5"

    #: A constant which can be used with the signing_algorithm property of a SignedData.
    #: This constant has a value of "SHA_384_RSA_PKCS1_V1_5"
    SIGNING_ALGORITHM_SHA_384_RSA_PKCS1_V1_5 = "SHA_384_RSA_PKCS1_V1_5"

    #: A constant which can be used with the signing_algorithm property of a SignedData.
    #: This constant has a value of "SHA_512_RSA_PKCS1_V1_5"
    SIGNING_ALGORITHM_SHA_512_RSA_PKCS1_V1_5 = "SHA_512_RSA_PKCS1_V1_5"

    #: A constant which can be used with the signing_algorithm property of a SignedData.
    #: This constant has a value of "ECDSA_SHA_256"
    SIGNING_ALGORITHM_ECDSA_SHA_256 = "ECDSA_SHA_256"

    #: A constant which can be used with the signing_algorithm property of a SignedData.
    #: This constant has a value of "ECDSA_SHA_384"
    SIGNING_ALGORITHM_ECDSA_SHA_384 = "ECDSA_SHA_384"

    #: A constant which can be used with the signing_algorithm property of a SignedData.
    #: This constant has a value of "ECDSA_SHA_512"
    SIGNING_ALGORITHM_ECDSA_SHA_512 = "ECDSA_SHA_512"

    def __init__(self, **kwargs):
        """
        Initializes a new SignedData object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key_id:
            The value to assign to the key_id property of this SignedData.
        :type key_id: str

        :param key_version_id:
            The value to assign to the key_version_id property of this SignedData.
        :type key_version_id: str

        :param signature:
            The value to assign to the signature property of this SignedData.
        :type signature: str

        :param signing_algorithm:
            The value to assign to the signing_algorithm property of this SignedData.
            Allowed values for this property are: "SHA_224_RSA_PKCS_PSS", "SHA_256_RSA_PKCS_PSS", "SHA_384_RSA_PKCS_PSS", "SHA_512_RSA_PKCS_PSS", "SHA_224_RSA_PKCS1_V1_5", "SHA_256_RSA_PKCS1_V1_5", "SHA_384_RSA_PKCS1_V1_5", "SHA_512_RSA_PKCS1_V1_5", "ECDSA_SHA_256", "ECDSA_SHA_384", "ECDSA_SHA_512", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type signing_algorithm: str

        """
        self.swagger_types = {
            'key_id': 'str',
            'key_version_id': 'str',
            'signature': 'str',
            'signing_algorithm': 'str'
        }

        self.attribute_map = {
            'key_id': 'keyId',
            'key_version_id': 'keyVersionId',
            'signature': 'signature',
            'signing_algorithm': 'signingAlgorithm'
        }

        self._key_id = None
        self._key_version_id = None
        self._signature = None
        self._signing_algorithm = None

    @property
    def key_id(self):
        """
        **[Required]** Gets the key_id of this SignedData.
        The OCID of the key used to sign the message.


        :return: The key_id of this SignedData.
        :rtype: str
        """
        return self._key_id

    @key_id.setter
    def key_id(self, key_id):
        """
        Sets the key_id of this SignedData.
        The OCID of the key used to sign the message.


        :param key_id: The key_id of this SignedData.
        :type: str
        """
        self._key_id = key_id

    @property
    def key_version_id(self):
        """
        **[Required]** Gets the key_version_id of this SignedData.
        The OCID of the key version used to sign the message.


        :return: The key_version_id of this SignedData.
        :rtype: str
        """
        return self._key_version_id

    @key_version_id.setter
    def key_version_id(self, key_version_id):
        """
        Sets the key_version_id of this SignedData.
        The OCID of the key version used to sign the message.


        :param key_version_id: The key_version_id of this SignedData.
        :type: str
        """
        self._key_version_id = key_version_id

    @property
    def signature(self):
        """
        **[Required]** Gets the signature of this SignedData.
        The base64-encoded binary data object denoting the cryptographic signature generated for the message or message digest.


        :return: The signature of this SignedData.
        :rtype: str
        """
        return self._signature

    @signature.setter
    def signature(self, signature):
        """
        Sets the signature of this SignedData.
        The base64-encoded binary data object denoting the cryptographic signature generated for the message or message digest.


        :param signature: The signature of this SignedData.
        :type: str
        """
        self._signature = signature

    @property
    def signing_algorithm(self):
        """
        **[Required]** Gets the signing_algorithm of this SignedData.
        The algorithm to use to sign the message or message digest.
        For RSA keys, supported signature schemes include PKCS #1 and RSASSA-PSS, along with
        different hashing algorithms.
        For ECDSA keys, ECDSA is the supported signature scheme with different hashing algorithms.
        When you pass a message digest for signing, ensure that you specify the same hashing algorithm
        as used when creating the message digest.

        Allowed values for this property are: "SHA_224_RSA_PKCS_PSS", "SHA_256_RSA_PKCS_PSS", "SHA_384_RSA_PKCS_PSS", "SHA_512_RSA_PKCS_PSS", "SHA_224_RSA_PKCS1_V1_5", "SHA_256_RSA_PKCS1_V1_5", "SHA_384_RSA_PKCS1_V1_5", "SHA_512_RSA_PKCS1_V1_5", "ECDSA_SHA_256", "ECDSA_SHA_384", "ECDSA_SHA_512", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The signing_algorithm of this SignedData.
        :rtype: str
        """
        return self._signing_algorithm

    @signing_algorithm.setter
    def signing_algorithm(self, signing_algorithm):
        """
        Sets the signing_algorithm of this SignedData.
        The algorithm to use to sign the message or message digest.
        For RSA keys, supported signature schemes include PKCS #1 and RSASSA-PSS, along with
        different hashing algorithms.
        For ECDSA keys, ECDSA is the supported signature scheme with different hashing algorithms.
        When you pass a message digest for signing, ensure that you specify the same hashing algorithm
        as used when creating the message digest.


        :param signing_algorithm: The signing_algorithm of this SignedData.
        :type: str
        """
        allowed_values = ["SHA_224_RSA_PKCS_PSS", "SHA_256_RSA_PKCS_PSS", "SHA_384_RSA_PKCS_PSS", "SHA_512_RSA_PKCS_PSS", "SHA_224_RSA_PKCS1_V1_5", "SHA_256_RSA_PKCS1_V1_5", "SHA_384_RSA_PKCS1_V1_5", "SHA_512_RSA_PKCS1_V1_5", "ECDSA_SHA_256", "ECDSA_SHA_384", "ECDSA_SHA_512"]
        if not value_allowed_none_or_none_sentinel(signing_algorithm, allowed_values):
            signing_algorithm = 'UNKNOWN_ENUM_VALUE'
        self._signing_algorithm = signing_algorithm

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SuggestResults(object):
    """
    The list of potential matches returned from the suggest operation for the given input text. The size of the list will be determined
    by the limit parameter.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SuggestResults object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param total_count:
            The value to assign to the total_count property of this SuggestResults.
        :type total_count: int

        :param search_latency_in_ms:
            The value to assign to the search_latency_in_ms property of this SuggestResults.
        :type search_latency_in_ms: int

        :param input_text:
            The value to assign to the input_text property of this SuggestResults.
        :type input_text: str

        :param items:
            The value to assign to the items property of this SuggestResults.
        :type items: list[oci.data_catalog.models.SuggestListItem]

        """
        self.swagger_types = {
            'total_count': 'int',
            'search_latency_in_ms': 'int',
            'input_text': 'str',
            'items': 'list[SuggestListItem]'
        }

        self.attribute_map = {
            'total_count': 'totalCount',
            'search_latency_in_ms': 'searchLatencyInMs',
            'input_text': 'inputText',
            'items': 'items'
        }

        self._total_count = None
        self._search_latency_in_ms = None
        self._input_text = None
        self._items = None

    @property
    def total_count(self):
        """
        **[Required]** Gets the total_count of this SuggestResults.
        Total number of items returned.


        :return: The total_count of this SuggestResults.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """
        Sets the total_count of this SuggestResults.
        Total number of items returned.


        :param total_count: The total_count of this SuggestResults.
        :type: int
        """
        self._total_count = total_count

    @property
    def search_latency_in_ms(self):
        """
        Gets the search_latency_in_ms of this SuggestResults.
        Time taken to compute the result, in milliseconds.


        :return: The search_latency_in_ms of this SuggestResults.
        :rtype: int
        """
        return self._search_latency_in_ms

    @search_latency_in_ms.setter
    def search_latency_in_ms(self, search_latency_in_ms):
        """
        Sets the search_latency_in_ms of this SuggestResults.
        Time taken to compute the result, in milliseconds.


        :param search_latency_in_ms: The search_latency_in_ms of this SuggestResults.
        :type: int
        """
        self._search_latency_in_ms = search_latency_in_ms

    @property
    def input_text(self):
        """
        **[Required]** Gets the input_text of this SuggestResults.
        Input string for which the potential matches are computed.


        :return: The input_text of this SuggestResults.
        :rtype: str
        """
        return self._input_text

    @input_text.setter
    def input_text(self, input_text):
        """
        Sets the input_text of this SuggestResults.
        Input string for which the potential matches are computed.


        :param input_text: The input_text of this SuggestResults.
        :type: str
        """
        self._input_text = input_text

    @property
    def items(self):
        """
        Gets the items of this SuggestResults.
        List of suggestions.


        :return: The items of this SuggestResults.
        :rtype: list[oci.data_catalog.models.SuggestListItem]
        """
        return self._items

    @items.setter
    def items(self, items):
        """
        Sets the items of this SuggestResults.
        List of suggestions.


        :param items: The items of this SuggestResults.
        :type: list[oci.data_catalog.models.SuggestListItem]
        """
        self._items = items

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ExternalDatabaseConnectorSummary(object):
    """
    An Oracle Cloud Infrastructure resource used to connect to an external Oracle Database.
    This resource stores the database connection string, user credentials, and related details that allow you to
    manage your external database using the Oracle Cloud Infrastructure Console and API interfaces.
    """

    #: A constant which can be used with the connector_type property of a ExternalDatabaseConnectorSummary.
    #: This constant has a value of "MACS"
    CONNECTOR_TYPE_MACS = "MACS"

    def __init__(self, **kwargs):
        """
        Initializes a new ExternalDatabaseConnectorSummary object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.database.models.ExternalMacsConnectorSummary`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this ExternalDatabaseConnectorSummary.
        :type compartment_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this ExternalDatabaseConnectorSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this ExternalDatabaseConnectorSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this ExternalDatabaseConnectorSummary.
        :type display_name: str

        :param id:
            The value to assign to the id property of this ExternalDatabaseConnectorSummary.
        :type id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this ExternalDatabaseConnectorSummary.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this ExternalDatabaseConnectorSummary.
        :type lifecycle_details: str

        :param time_created:
            The value to assign to the time_created property of this ExternalDatabaseConnectorSummary.
        :type time_created: datetime

        :param connector_type:
            The value to assign to the connector_type property of this ExternalDatabaseConnectorSummary.
            Allowed values for this property are: "MACS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type connector_type: str

        :param external_database_id:
            The value to assign to the external_database_id property of this ExternalDatabaseConnectorSummary.
        :type external_database_id: str

        :param connection_status:
            The value to assign to the connection_status property of this ExternalDatabaseConnectorSummary.
        :type connection_status: str

        :param time_connection_status_last_updated:
            The value to assign to the time_connection_status_last_updated property of this ExternalDatabaseConnectorSummary.
        :type time_connection_status_last_updated: datetime

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'id': 'str',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'time_created': 'datetime',
            'connector_type': 'str',
            'external_database_id': 'str',
            'connection_status': 'str',
            'time_connection_status_last_updated': 'datetime'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'id': 'id',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'time_created': 'timeCreated',
            'connector_type': 'connectorType',
            'external_database_id': 'externalDatabaseId',
            'connection_status': 'connectionStatus',
            'time_connection_status_last_updated': 'timeConnectionStatusLastUpdated'
        }

        self._compartment_id = None
        self._freeform_tags = None
        self._defined_tags = None
        self._display_name = None
        self._id = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._time_created = None
        self._connector_type = None
        self._external_database_id = None
        self._connection_status = None
        self._time_connection_status_last_updated = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['connectorType']

        if type == 'MACS':
            return 'ExternalMacsConnectorSummary'
        else:
            return 'ExternalDatabaseConnectorSummary'

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ExternalDatabaseConnectorSummary.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this ExternalDatabaseConnectorSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ExternalDatabaseConnectorSummary.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this ExternalDatabaseConnectorSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this ExternalDatabaseConnectorSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this ExternalDatabaseConnectorSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this ExternalDatabaseConnectorSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this ExternalDatabaseConnectorSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this ExternalDatabaseConnectorSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this ExternalDatabaseConnectorSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this ExternalDatabaseConnectorSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this ExternalDatabaseConnectorSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this ExternalDatabaseConnectorSummary.
        The user-friendly name for the
        :func:`create_external_database_connector_details`.
        The name does not have to be unique.


        :return: The display_name of this ExternalDatabaseConnectorSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ExternalDatabaseConnectorSummary.
        The user-friendly name for the
        :func:`create_external_database_connector_details`.
        The name does not have to be unique.


        :param display_name: The display_name of this ExternalDatabaseConnectorSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ExternalDatabaseConnectorSummary.
        The `OCID`__ of the
        :func:`create_external_database_connector_details`.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this ExternalDatabaseConnectorSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ExternalDatabaseConnectorSummary.
        The `OCID`__ of the
        :func:`create_external_database_connector_details`.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this ExternalDatabaseConnectorSummary.
        :type: str
        """
        self._id = id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this ExternalDatabaseConnectorSummary.
        The current lifecycle state of the external database connector resource.


        :return: The lifecycle_state of this ExternalDatabaseConnectorSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this ExternalDatabaseConnectorSummary.
        The current lifecycle state of the external database connector resource.


        :param lifecycle_state: The lifecycle_state of this ExternalDatabaseConnectorSummary.
        :type: str
        """
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this ExternalDatabaseConnectorSummary.
        Additional information about the current lifecycle state.


        :return: The lifecycle_details of this ExternalDatabaseConnectorSummary.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this ExternalDatabaseConnectorSummary.
        Additional information about the current lifecycle state.


        :param lifecycle_details: The lifecycle_details of this ExternalDatabaseConnectorSummary.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this ExternalDatabaseConnectorSummary.
        The date and time the external connector was created.


        :return: The time_created of this ExternalDatabaseConnectorSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ExternalDatabaseConnectorSummary.
        The date and time the external connector was created.


        :param time_created: The time_created of this ExternalDatabaseConnectorSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def connector_type(self):
        """
        **[Required]** Gets the connector_type of this ExternalDatabaseConnectorSummary.
        The type of connector used by the external database resource.

        Allowed values for this property are: "MACS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The connector_type of this ExternalDatabaseConnectorSummary.
        :rtype: str
        """
        return self._connector_type

    @connector_type.setter
    def connector_type(self, connector_type):
        """
        Sets the connector_type of this ExternalDatabaseConnectorSummary.
        The type of connector used by the external database resource.


        :param connector_type: The connector_type of this ExternalDatabaseConnectorSummary.
        :type: str
        """
        allowed_values = ["MACS"]
        if not value_allowed_none_or_none_sentinel(connector_type, allowed_values):
            connector_type = 'UNKNOWN_ENUM_VALUE'
        self._connector_type = connector_type

    @property
    def external_database_id(self):
        """
        **[Required]** Gets the external_database_id of this ExternalDatabaseConnectorSummary.
        The `OCID`__ of the external database resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The external_database_id of this ExternalDatabaseConnectorSummary.
        :rtype: str
        """
        return self._external_database_id

    @external_database_id.setter
    def external_database_id(self, external_database_id):
        """
        Sets the external_database_id of this ExternalDatabaseConnectorSummary.
        The `OCID`__ of the external database resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param external_database_id: The external_database_id of this ExternalDatabaseConnectorSummary.
        :type: str
        """
        self._external_database_id = external_database_id

    @property
    def connection_status(self):
        """
        **[Required]** Gets the connection_status of this ExternalDatabaseConnectorSummary.
        The status of connectivity to the external database.


        :return: The connection_status of this ExternalDatabaseConnectorSummary.
        :rtype: str
        """
        return self._connection_status

    @connection_status.setter
    def connection_status(self, connection_status):
        """
        Sets the connection_status of this ExternalDatabaseConnectorSummary.
        The status of connectivity to the external database.


        :param connection_status: The connection_status of this ExternalDatabaseConnectorSummary.
        :type: str
        """
        self._connection_status = connection_status

    @property
    def time_connection_status_last_updated(self):
        """
        **[Required]** Gets the time_connection_status_last_updated of this ExternalDatabaseConnectorSummary.
        The date and time the `connectionStatus` of this external connector was last updated.


        :return: The time_connection_status_last_updated of this ExternalDatabaseConnectorSummary.
        :rtype: datetime
        """
        return self._time_connection_status_last_updated

    @time_connection_status_last_updated.setter
    def time_connection_status_last_updated(self, time_connection_status_last_updated):
        """
        Sets the time_connection_status_last_updated of this ExternalDatabaseConnectorSummary.
        The date and time the `connectionStatus` of this external connector was last updated.


        :param time_connection_status_last_updated: The time_connection_status_last_updated of this ExternalDatabaseConnectorSummary.
        :type: datetime
        """
        self._time_connection_status_last_updated = time_connection_status_last_updated

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateReplicat(object):
    """
    Note: Deprecated. Use the new resource model APIs instead.
    Parameters for GoldenGate Replicat processes.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateReplicat object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param map_parallelism:
            The value to assign to the map_parallelism property of this CreateReplicat.
        :type map_parallelism: int

        :param min_apply_parallelism:
            The value to assign to the min_apply_parallelism property of this CreateReplicat.
        :type min_apply_parallelism: int

        :param max_apply_parallelism:
            The value to assign to the max_apply_parallelism property of this CreateReplicat.
        :type max_apply_parallelism: int

        """
        self.swagger_types = {
            'map_parallelism': 'int',
            'min_apply_parallelism': 'int',
            'max_apply_parallelism': 'int'
        }

        self.attribute_map = {
            'map_parallelism': 'mapParallelism',
            'min_apply_parallelism': 'minApplyParallelism',
            'max_apply_parallelism': 'maxApplyParallelism'
        }

        self._map_parallelism = None
        self._min_apply_parallelism = None
        self._max_apply_parallelism = None

    @property
    def map_parallelism(self):
        """
        Gets the map_parallelism of this CreateReplicat.
        Number of threads used to read trail files (valid for Parallel Replicat)


        :return: The map_parallelism of this CreateReplicat.
        :rtype: int
        """
        return self._map_parallelism

    @map_parallelism.setter
    def map_parallelism(self, map_parallelism):
        """
        Sets the map_parallelism of this CreateReplicat.
        Number of threads used to read trail files (valid for Parallel Replicat)


        :param map_parallelism: The map_parallelism of this CreateReplicat.
        :type: int
        """
        self._map_parallelism = map_parallelism

    @property
    def min_apply_parallelism(self):
        """
        Gets the min_apply_parallelism of this CreateReplicat.
        Defines the range in which the Replicat automatically adjusts its apply parallelism (valid for Parallel Replicat)


        :return: The min_apply_parallelism of this CreateReplicat.
        :rtype: int
        """
        return self._min_apply_parallelism

    @min_apply_parallelism.setter
    def min_apply_parallelism(self, min_apply_parallelism):
        """
        Sets the min_apply_parallelism of this CreateReplicat.
        Defines the range in which the Replicat automatically adjusts its apply parallelism (valid for Parallel Replicat)


        :param min_apply_parallelism: The min_apply_parallelism of this CreateReplicat.
        :type: int
        """
        self._min_apply_parallelism = min_apply_parallelism

    @property
    def max_apply_parallelism(self):
        """
        Gets the max_apply_parallelism of this CreateReplicat.
        Defines the range in which the Replicat automatically adjusts its apply parallelism (valid for Parallel Replicat)


        :return: The max_apply_parallelism of this CreateReplicat.
        :rtype: int
        """
        return self._max_apply_parallelism

    @max_apply_parallelism.setter
    def max_apply_parallelism(self, max_apply_parallelism):
        """
        Sets the max_apply_parallelism of this CreateReplicat.
        Defines the range in which the Replicat automatically adjusts its apply parallelism (valid for Parallel Replicat)


        :param max_apply_parallelism: The max_apply_parallelism of this CreateReplicat.
        :type: int
        """
        self._max_apply_parallelism = max_apply_parallelism

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseTimeAggregateMetrics(object):
    """
    The database time metric details.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseTimeAggregateMetrics object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param cpu_count:
            The value to assign to the cpu_count property of this DatabaseTimeAggregateMetrics.
        :type cpu_count: oci.database_management.models.MetricDataPoint

        :param cpu_time:
            The value to assign to the cpu_time property of this DatabaseTimeAggregateMetrics.
        :type cpu_time: oci.database_management.models.MetricDataPoint

        :param wait_time:
            The value to assign to the wait_time property of this DatabaseTimeAggregateMetrics.
        :type wait_time: oci.database_management.models.MetricDataPoint

        :param user_io_time:
            The value to assign to the user_io_time property of this DatabaseTimeAggregateMetrics.
        :type user_io_time: oci.database_management.models.MetricDataPoint

        :param cluster:
            The value to assign to the cluster property of this DatabaseTimeAggregateMetrics.
        :type cluster: oci.database_management.models.MetricDataPoint

        """
        self.swagger_types = {
            'cpu_count': 'MetricDataPoint',
            'cpu_time': 'MetricDataPoint',
            'wait_time': 'MetricDataPoint',
            'user_io_time': 'MetricDataPoint',
            'cluster': 'MetricDataPoint'
        }

        self.attribute_map = {
            'cpu_count': 'cpuCount',
            'cpu_time': 'cpuTime',
            'wait_time': 'waitTime',
            'user_io_time': 'userIoTime',
            'cluster': 'cluster'
        }

        self._cpu_count = None
        self._cpu_time = None
        self._wait_time = None
        self._user_io_time = None
        self._cluster = None

    @property
    def cpu_count(self):
        """
        Gets the cpu_count of this DatabaseTimeAggregateMetrics.

        :return: The cpu_count of this DatabaseTimeAggregateMetrics.
        :rtype: oci.database_management.models.MetricDataPoint
        """
        return self._cpu_count

    @cpu_count.setter
    def cpu_count(self, cpu_count):
        """
        Sets the cpu_count of this DatabaseTimeAggregateMetrics.

        :param cpu_count: The cpu_count of this DatabaseTimeAggregateMetrics.
        :type: oci.database_management.models.MetricDataPoint
        """
        self._cpu_count = cpu_count

    @property
    def cpu_time(self):
        """
        Gets the cpu_time of this DatabaseTimeAggregateMetrics.

        :return: The cpu_time of this DatabaseTimeAggregateMetrics.
        :rtype: oci.database_management.models.MetricDataPoint
        """
        return self._cpu_time

    @cpu_time.setter
    def cpu_time(self, cpu_time):
        """
        Sets the cpu_time of this DatabaseTimeAggregateMetrics.

        :param cpu_time: The cpu_time of this DatabaseTimeAggregateMetrics.
        :type: oci.database_management.models.MetricDataPoint
        """
        self._cpu_time = cpu_time

    @property
    def wait_time(self):
        """
        Gets the wait_time of this DatabaseTimeAggregateMetrics.

        :return: The wait_time of this DatabaseTimeAggregateMetrics.
        :rtype: oci.database_management.models.MetricDataPoint
        """
        return self._wait_time

    @wait_time.setter
    def wait_time(self, wait_time):
        """
        Sets the wait_time of this DatabaseTimeAggregateMetrics.

        :param wait_time: The wait_time of this DatabaseTimeAggregateMetrics.
        :type: oci.database_management.models.MetricDataPoint
        """
        self._wait_time = wait_time

    @property
    def user_io_time(self):
        """
        Gets the user_io_time of this DatabaseTimeAggregateMetrics.

        :return: The user_io_time of this DatabaseTimeAggregateMetrics.
        :rtype: oci.database_management.models.MetricDataPoint
        """
        return self._user_io_time

    @user_io_time.setter
    def user_io_time(self, user_io_time):
        """
        Sets the user_io_time of this DatabaseTimeAggregateMetrics.

        :param user_io_time: The user_io_time of this DatabaseTimeAggregateMetrics.
        :type: oci.database_management.models.MetricDataPoint
        """
        self._user_io_time = user_io_time

    @property
    def cluster(self):
        """
        Gets the cluster of this DatabaseTimeAggregateMetrics.

        :return: The cluster of this DatabaseTimeAggregateMetrics.
        :rtype: oci.database_management.models.MetricDataPoint
        """
        return self._cluster

    @cluster.setter
    def cluster(self, cluster):
        """
        Sets the cluster of this DatabaseTimeAggregateMetrics.

        :param cluster: The cluster of this DatabaseTimeAggregateMetrics.
        :type: oci.database_management.models.MetricDataPoint
        """
        self._cluster = cluster

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AnalyticsClusterTableMemoryEstimate(object):
    """
    DEPRECATED -- please use HeatWave API instead.
    Estimated memory footprint for a MySQL user table
    when loaded to the Analytics Cluster memory.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AnalyticsClusterTableMemoryEstimate object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param table_name:
            The value to assign to the table_name property of this AnalyticsClusterTableMemoryEstimate.
        :type table_name: str

        :param to_load_column_count:
            The value to assign to the to_load_column_count property of this AnalyticsClusterTableMemoryEstimate.
        :type to_load_column_count: int

        :param varlen_column_count:
            The value to assign to the varlen_column_count property of this AnalyticsClusterTableMemoryEstimate.
        :type varlen_column_count: int

        :param estimated_row_count:
            The value to assign to the estimated_row_count property of this AnalyticsClusterTableMemoryEstimate.
        :type estimated_row_count: int

        :param analytical_footprint_in_mbs:
            The value to assign to the analytical_footprint_in_mbs property of this AnalyticsClusterTableMemoryEstimate.
        :type analytical_footprint_in_mbs: int

        :param error_comment:
            The value to assign to the error_comment property of this AnalyticsClusterTableMemoryEstimate.
        :type error_comment: str

        """
        self.swagger_types = {
            'table_name': 'str',
            'to_load_column_count': 'int',
            'varlen_column_count': 'int',
            'estimated_row_count': 'int',
            'analytical_footprint_in_mbs': 'int',
            'error_comment': 'str'
        }

        self.attribute_map = {
            'table_name': 'tableName',
            'to_load_column_count': 'toLoadColumnCount',
            'varlen_column_count': 'varlenColumnCount',
            'estimated_row_count': 'estimatedRowCount',
            'analytical_footprint_in_mbs': 'analyticalFootprintInMbs',
            'error_comment': 'errorComment'
        }

        self._table_name = None
        self._to_load_column_count = None
        self._varlen_column_count = None
        self._estimated_row_count = None
        self._analytical_footprint_in_mbs = None
        self._error_comment = None

    @property
    def table_name(self):
        """
        **[Required]** Gets the table_name of this AnalyticsClusterTableMemoryEstimate.
        The table name.


        :return: The table_name of this AnalyticsClusterTableMemoryEstimate.
        :rtype: str
        """
        return self._table_name

    @table_name.setter
    def table_name(self, table_name):
        """
        Sets the table_name of this AnalyticsClusterTableMemoryEstimate.
        The table name.


        :param table_name: The table_name of this AnalyticsClusterTableMemoryEstimate.
        :type: str
        """
        self._table_name = table_name

    @property
    def to_load_column_count(self):
        """
        **[Required]** Gets the to_load_column_count of this AnalyticsClusterTableMemoryEstimate.
        The number of columns to be loaded to Analytics Cluster memory.
        These columns contribute to the analytical memory footprint.


        :return: The to_load_column_count of this AnalyticsClusterTableMemoryEstimate.
        :rtype: int
        """
        return self._to_load_column_count

    @to_load_column_count.setter
    def to_load_column_count(self, to_load_column_count):
        """
        Sets the to_load_column_count of this AnalyticsClusterTableMemoryEstimate.
        The number of columns to be loaded to Analytics Cluster memory.
        These columns contribute to the analytical memory footprint.


        :param to_load_column_count: The to_load_column_count of this AnalyticsClusterTableMemoryEstimate.
        :type: int
        """
        self._to_load_column_count = to_load_column_count

    @property
    def varlen_column_count(self):
        """
        **[Required]** Gets the varlen_column_count of this AnalyticsClusterTableMemoryEstimate.
        The number of variable-length columns to be loaded to Analytics Cluster memory.
        These columns contribute to the analytical memory footprint.


        :return: The varlen_column_count of this AnalyticsClusterTableMemoryEstimate.
        :rtype: int
        """
        return self._varlen_column_count

    @varlen_column_count.setter
    def varlen_column_count(self, varlen_column_count):
        """
        Sets the varlen_column_count of this AnalyticsClusterTableMemoryEstimate.
        The number of variable-length columns to be loaded to Analytics Cluster memory.
        These columns contribute to the analytical memory footprint.


        :param varlen_column_count: The varlen_column_count of this AnalyticsClusterTableMemoryEstimate.
        :type: int
        """
        self._varlen_column_count = varlen_column_count

    @property
    def estimated_row_count(self):
        """
        **[Required]** Gets the estimated_row_count of this AnalyticsClusterTableMemoryEstimate.
        The estimated number of rows in the table. This number was used to
        derive the analytical memory footprint.


        :return: The estimated_row_count of this AnalyticsClusterTableMemoryEstimate.
        :rtype: int
        """
        return self._estimated_row_count

    @estimated_row_count.setter
    def estimated_row_count(self, estimated_row_count):
        """
        Sets the estimated_row_count of this AnalyticsClusterTableMemoryEstimate.
        The estimated number of rows in the table. This number was used to
        derive the analytical memory footprint.


        :param estimated_row_count: The estimated_row_count of this AnalyticsClusterTableMemoryEstimate.
        :type: int
        """
        self._estimated_row_count = estimated_row_count

    @property
    def analytical_footprint_in_mbs(self):
        """
        **[Required]** Gets the analytical_footprint_in_mbs of this AnalyticsClusterTableMemoryEstimate.
        The estimated memory footprint of the table in MBs when loaded to
        Analytics Cluster memory (null if the table cannot be loaded to the
        Analytics Cluster).


        :return: The analytical_footprint_in_mbs of this AnalyticsClusterTableMemoryEstimate.
        :rtype: int
        """
        return self._analytical_footprint_in_mbs

    @analytical_footprint_in_mbs.setter
    def analytical_footprint_in_mbs(self, analytical_footprint_in_mbs):
        """
        Sets the analytical_footprint_in_mbs of this AnalyticsClusterTableMemoryEstimate.
        The estimated memory footprint of the table in MBs when loaded to
        Analytics Cluster memory (null if the table cannot be loaded to the
        Analytics Cluster).


        :param analytical_footprint_in_mbs: The analytical_footprint_in_mbs of this AnalyticsClusterTableMemoryEstimate.
        :type: int
        """
        self._analytical_footprint_in_mbs = analytical_footprint_in_mbs

    @property
    def error_comment(self):
        """
        **[Required]** Gets the error_comment of this AnalyticsClusterTableMemoryEstimate.
        Error comment (empty string if no errors occured).


        :return: The error_comment of this AnalyticsClusterTableMemoryEstimate.
        :rtype: str
        """
        return self._error_comment

    @error_comment.setter
    def error_comment(self, error_comment):
        """
        Sets the error_comment of this AnalyticsClusterTableMemoryEstimate.
        Error comment (empty string if no errors occured).


        :param error_comment: The error_comment of this AnalyticsClusterTableMemoryEstimate.
        :type: str
        """
        self._error_comment = error_comment

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .add_user_to_group_details import AddUserToGroupDetails
from .api_key import ApiKey
from .auth_token import AuthToken
from .authentication_policy import AuthenticationPolicy
from .availability_domain import AvailabilityDomain
from .base_tag_definition_validator import BaseTagDefinitionValidator
from .bulk_action_resource import BulkActionResource
from .bulk_action_resource_type import BulkActionResourceType
from .bulk_action_resource_type_collection import BulkActionResourceTypeCollection
from .bulk_delete_resources_details import BulkDeleteResourcesDetails
from .bulk_delete_tags_details import BulkDeleteTagsDetails
from .bulk_edit_operation_details import BulkEditOperationDetails
from .bulk_edit_resource import BulkEditResource
from .bulk_edit_tags_details import BulkEditTagsDetails
from .bulk_edit_tags_resource_type import BulkEditTagsResourceType
from .bulk_edit_tags_resource_type_collection import BulkEditTagsResourceTypeCollection
from .bulk_move_resources_details import BulkMoveResourcesDetails
from .change_tag_namespace_compartment_detail import ChangeTagNamespaceCompartmentDetail
from .compartment import Compartment
from .create_api_key_details import CreateApiKeyDetails
from .create_auth_token_details import CreateAuthTokenDetails
from .create_compartment_details import CreateCompartmentDetails
from .create_customer_secret_key_details import CreateCustomerSecretKeyDetails
from .create_dynamic_group_details import CreateDynamicGroupDetails
from .create_group_details import CreateGroupDetails
from .create_identity_provider_details import CreateIdentityProviderDetails
from .create_idp_group_mapping_details import CreateIdpGroupMappingDetails
from .create_network_source_details import CreateNetworkSourceDetails
from .create_o_auth2_client_credential_details import CreateOAuth2ClientCredentialDetails
from .create_policy_details import CreatePolicyDetails
from .create_region_subscription_details import CreateRegionSubscriptionDetails
from .create_saml2_identity_provider_details import CreateSaml2IdentityProviderDetails
from .create_smtp_credential_details import CreateSmtpCredentialDetails
from .create_swift_password_details import CreateSwiftPasswordDetails
from .create_tag_default_details import CreateTagDefaultDetails
from .create_tag_details import CreateTagDetails
from .create_tag_namespace_details import CreateTagNamespaceDetails
from .create_user_details import CreateUserDetails
from .customer_secret_key import CustomerSecretKey
from .customer_secret_key_summary import CustomerSecretKeySummary
from .default_tag_definition_validator import DefaultTagDefinitionValidator
from .dynamic_group import DynamicGroup
from .enum_tag_definition_validator import EnumTagDefinitionValidator
from .fault_domain import FaultDomain
from .fully_qualified_scope import FullyQualifiedScope
from .group import Group
from .identity_provider import IdentityProvider
from .identity_provider_group_summary import IdentityProviderGroupSummary
from .idp_group_mapping import IdpGroupMapping
from .mfa_totp_device import MfaTotpDevice
from .mfa_totp_device_summary import MfaTotpDeviceSummary
from .mfa_totp_token import MfaTotpToken
from .move_compartment_details import MoveCompartmentDetails
from .network_policy import NetworkPolicy
from .network_sources import NetworkSources
from .network_sources_summary import NetworkSourcesSummary
from .network_sources_virtual_source_list import NetworkSourcesVirtualSourceList
from .o_auth2_client_credential import OAuth2ClientCredential
from .o_auth2_client_credential_summary import OAuth2ClientCredentialSummary
from .password_policy import PasswordPolicy
from .policy import Policy
from .region import Region
from .region_subscription import RegionSubscription
from .saml2_identity_provider import Saml2IdentityProvider
from .scim_client_credentials import ScimClientCredentials
from .smtp_credential import SmtpCredential
from .smtp_credential_summary import SmtpCredentialSummary
from .swift_password import SwiftPassword
from .tag import Tag
from .tag_default import TagDefault
from .tag_default_summary import TagDefaultSummary
from .tag_namespace import TagNamespace
from .tag_namespace_summary import TagNamespaceSummary
from .tag_summary import TagSummary
from .tagging_work_request import TaggingWorkRequest
from .tagging_work_request_error_summary import TaggingWorkRequestErrorSummary
from .tagging_work_request_log_summary import TaggingWorkRequestLogSummary
from .tagging_work_request_summary import TaggingWorkRequestSummary
from .tenancy import Tenancy
from .ui_password import UIPassword
from .ui_password_information import UIPasswordInformation
from .update_auth_token_details import UpdateAuthTokenDetails
from .update_authentication_policy_details import UpdateAuthenticationPolicyDetails
from .update_compartment_details import UpdateCompartmentDetails
from .update_customer_secret_key_details import UpdateCustomerSecretKeyDetails
from .update_dynamic_group_details import UpdateDynamicGroupDetails
from .update_group_details import UpdateGroupDetails
from .update_identity_provider_details import UpdateIdentityProviderDetails
from .update_idp_group_mapping_details import UpdateIdpGroupMappingDetails
from .update_network_source_details import UpdateNetworkSourceDetails
from .update_o_auth2_client_credential_details import UpdateOAuth2ClientCredentialDetails
from .update_policy_details import UpdatePolicyDetails
from .update_saml2_identity_provider_details import UpdateSaml2IdentityProviderDetails
from .update_smtp_credential_details import UpdateSmtpCredentialDetails
from .update_state_details import UpdateStateDetails
from .update_swift_password_details import UpdateSwiftPasswordDetails
from .update_tag_default_details import UpdateTagDefaultDetails
from .update_tag_details import UpdateTagDetails
from .update_tag_namespace_details import UpdateTagNamespaceDetails
from .update_user_capabilities_details import UpdateUserCapabilitiesDetails
from .update_user_details import UpdateUserDetails
from .user import User
from .user_capabilities import UserCapabilities
from .user_group_membership import UserGroupMembership
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary

# Maps type names to classes for identity services.
identity_type_mapping = {
    "AddUserToGroupDetails": AddUserToGroupDetails,
    "ApiKey": ApiKey,
    "AuthToken": AuthToken,
    "AuthenticationPolicy": AuthenticationPolicy,
    "AvailabilityDomain": AvailabilityDomain,
    "BaseTagDefinitionValidator": BaseTagDefinitionValidator,
    "BulkActionResource": BulkActionResource,
    "BulkActionResourceType": BulkActionResourceType,
    "BulkActionResourceTypeCollection": BulkActionResourceTypeCollection,
    "BulkDeleteResourcesDetails": BulkDeleteResourcesDetails,
    "BulkDeleteTagsDetails": BulkDeleteTagsDetails,
    "BulkEditOperationDetails": BulkEditOperationDetails,
    "BulkEditResource": BulkEditResource,
    "BulkEditTagsDetails": BulkEditTagsDetails,
    "BulkEditTagsResourceType": BulkEditTagsResourceType,
    "BulkEditTagsResourceTypeCollection": BulkEditTagsResourceTypeCollection,
    "BulkMoveResourcesDetails": BulkMoveResourcesDetails,
    "ChangeTagNamespaceCompartmentDetail": ChangeTagNamespaceCompartmentDetail,
    "Compartment": Compartment,
    "CreateApiKeyDetails": CreateApiKeyDetails,
    "CreateAuthTokenDetails": CreateAuthTokenDetails,
    "CreateCompartmentDetails": CreateCompartmentDetails,
    "CreateCustomerSecretKeyDetails": CreateCustomerSecretKeyDetails,
    "CreateDynamicGroupDetails": CreateDynamicGroupDetails,
    "CreateGroupDetails": CreateGroupDetails,
    "CreateIdentityProviderDetails": CreateIdentityProviderDetails,
    "CreateIdpGroupMappingDetails": CreateIdpGroupMappingDetails,
    "CreateNetworkSourceDetails": CreateNetworkSourceDetails,
    "CreateOAuth2ClientCredentialDetails": CreateOAuth2ClientCredentialDetails,
    "CreatePolicyDetails": CreatePolicyDetails,
    "CreateRegionSubscriptionDetails": CreateRegionSubscriptionDetails,
    "CreateSaml2IdentityProviderDetails": CreateSaml2IdentityProviderDetails,
    "CreateSmtpCredentialDetails": CreateSmtpCredentialDetails,
    "CreateSwiftPasswordDetails": CreateSwiftPasswordDetails,
    "CreateTagDefaultDetails": CreateTagDefaultDetails,
    "CreateTagDetails": CreateTagDetails,
    "CreateTagNamespaceDetails": CreateTagNamespaceDetails,
    "CreateUserDetails": CreateUserDetails,
    "CustomerSecretKey": CustomerSecretKey,
    "CustomerSecretKeySummary": CustomerSecretKeySummary,
    "DefaultTagDefinitionValidator": DefaultTagDefinitionValidator,
    "DynamicGroup": DynamicGroup,
    "EnumTagDefinitionValidator": EnumTagDefinitionValidator,
    "FaultDomain": FaultDomain,
    "FullyQualifiedScope": FullyQualifiedScope,
    "Group": Group,
    "IdentityProvider": IdentityProvider,
    "IdentityProviderGroupSummary": IdentityProviderGroupSummary,
    "IdpGroupMapping": IdpGroupMapping,
    "MfaTotpDevice": MfaTotpDevice,
    "MfaTotpDeviceSummary": MfaTotpDeviceSummary,
    "MfaTotpToken": MfaTotpToken,
    "MoveCompartmentDetails": MoveCompartmentDetails,
    "NetworkPolicy": NetworkPolicy,
    "NetworkSources": NetworkSources,
    "NetworkSourcesSummary": NetworkSourcesSummary,
    "NetworkSourcesVirtualSourceList": NetworkSourcesVirtualSourceList,
    "OAuth2ClientCredential": OAuth2ClientCredential,
    "OAuth2ClientCredentialSummary": OAuth2ClientCredentialSummary,
    "PasswordPolicy": PasswordPolicy,
    "Policy": Policy,
    "Region": Region,
    "RegionSubscription": RegionSubscription,
    "Saml2IdentityProvider": Saml2IdentityProvider,
    "ScimClientCredentials": ScimClientCredentials,
    "SmtpCredential": SmtpCredential,
    "SmtpCredentialSummary": SmtpCredentialSummary,
    "SwiftPassword": SwiftPassword,
    "Tag": Tag,
    "TagDefault": TagDefault,
    "TagDefaultSummary": TagDefaultSummary,
    "TagNamespace": TagNamespace,
    "TagNamespaceSummary": TagNamespaceSummary,
    "TagSummary": TagSummary,
    "TaggingWorkRequest": TaggingWorkRequest,
    "TaggingWorkRequestErrorSummary": TaggingWorkRequestErrorSummary,
    "TaggingWorkRequestLogSummary": TaggingWorkRequestLogSummary,
    "TaggingWorkRequestSummary": TaggingWorkRequestSummary,
    "Tenancy": Tenancy,
    "UIPassword": UIPassword,
    "UIPasswordInformation": UIPasswordInformation,
    "UpdateAuthTokenDetails": UpdateAuthTokenDetails,
    "UpdateAuthenticationPolicyDetails": UpdateAuthenticationPolicyDetails,
    "UpdateCompartmentDetails": UpdateCompartmentDetails,
    "UpdateCustomerSecretKeyDetails": UpdateCustomerSecretKeyDetails,
    "UpdateDynamicGroupDetails": UpdateDynamicGroupDetails,
    "UpdateGroupDetails": UpdateGroupDetails,
    "UpdateIdentityProviderDetails": UpdateIdentityProviderDetails,
    "UpdateIdpGroupMappingDetails": UpdateIdpGroupMappingDetails,
    "UpdateNetworkSourceDetails": UpdateNetworkSourceDetails,
    "UpdateOAuth2ClientCredentialDetails": UpdateOAuth2ClientCredentialDetails,
    "UpdatePolicyDetails": UpdatePolicyDetails,
    "UpdateSaml2IdentityProviderDetails": UpdateSaml2IdentityProviderDetails,
    "UpdateSmtpCredentialDetails": UpdateSmtpCredentialDetails,
    "UpdateStateDetails": UpdateStateDetails,
    "UpdateSwiftPasswordDetails": UpdateSwiftPasswordDetails,
    "UpdateTagDefaultDetails": UpdateTagDefaultDetails,
    "UpdateTagDetails": UpdateTagDetails,
    "UpdateTagNamespaceDetails": UpdateTagNamespaceDetails,
    "UpdateUserCapabilitiesDetails": UpdateUserCapabilitiesDetails,
    "UpdateUserDetails": UpdateUserDetails,
    "User": User,
    "UserCapabilities": UserCapabilities,
    "UserGroupMembership": UserGroupMembership,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .operator import Operator
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Target(Operator):
    """
    The information about the target operator. The target operator lets you specify the data entity to store the transformed data.
    """

    #: A constant which can be used with the data_property property of a Target.
    #: This constant has a value of "TRUNCATE"
    DATA_PROPERTY_TRUNCATE = "TRUNCATE"

    #: A constant which can be used with the data_property property of a Target.
    #: This constant has a value of "MERGE"
    DATA_PROPERTY_MERGE = "MERGE"

    #: A constant which can be used with the data_property property of a Target.
    #: This constant has a value of "BACKUP"
    DATA_PROPERTY_BACKUP = "BACKUP"

    #: A constant which can be used with the data_property property of a Target.
    #: This constant has a value of "OVERWRITE"
    DATA_PROPERTY_OVERWRITE = "OVERWRITE"

    #: A constant which can be used with the data_property property of a Target.
    #: This constant has a value of "APPEND"
    DATA_PROPERTY_APPEND = "APPEND"

    #: A constant which can be used with the data_property property of a Target.
    #: This constant has a value of "IGNORE"
    DATA_PROPERTY_IGNORE = "IGNORE"

    def __init__(self, **kwargs):
        """
        Initializes a new Target object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.Target.model_type` attribute
        of this class is ``TARGET_OPERATOR`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this Target.
            Allowed values for this property are: "SOURCE_OPERATOR", "FILTER_OPERATOR", "JOINER_OPERATOR", "AGGREGATOR_OPERATOR", "PROJECTION_OPERATOR", "TARGET_OPERATOR", "DISTINCT_OPERATOR", "SORT_OPERATOR", "UNION_OPERATOR", "INTERSECT_OPERATOR", "MINUS_OPERATOR", "MERGE_OPERATOR", "START_OPERATOR", "END_OPERATOR", "PIPELINE_OPERATOR", "TASK_OPERATOR", "EXPRESSION_OPERATOR", "LOOKUP_OPERATOR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type model_type: str

        :param key:
            The value to assign to the key property of this Target.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this Target.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this Target.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param name:
            The value to assign to the name property of this Target.
        :type name: str

        :param description:
            The value to assign to the description property of this Target.
        :type description: str

        :param object_version:
            The value to assign to the object_version property of this Target.
        :type object_version: int

        :param input_ports:
            The value to assign to the input_ports property of this Target.
        :type input_ports: list[oci.data_integration.models.InputPort]

        :param output_ports:
            The value to assign to the output_ports property of this Target.
        :type output_ports: list[oci.data_integration.models.OutputPort]

        :param object_status:
            The value to assign to the object_status property of this Target.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this Target.
        :type identifier: str

        :param parameters:
            The value to assign to the parameters property of this Target.
        :type parameters: list[oci.data_integration.models.Parameter]

        :param op_config_values:
            The value to assign to the op_config_values property of this Target.
        :type op_config_values: oci.data_integration.models.ConfigValues

        :param entity:
            The value to assign to the entity property of this Target.
        :type entity: oci.data_integration.models.DataEntity

        :param is_read_access:
            The value to assign to the is_read_access property of this Target.
        :type is_read_access: bool

        :param is_copy_fields:
            The value to assign to the is_copy_fields property of this Target.
        :type is_copy_fields: bool

        :param is_predefined_shape:
            The value to assign to the is_predefined_shape property of this Target.
        :type is_predefined_shape: bool

        :param data_property:
            The value to assign to the data_property property of this Target.
            Allowed values for this property are: "TRUNCATE", "MERGE", "BACKUP", "OVERWRITE", "APPEND", "IGNORE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type data_property: str

        :param schema_drift_config:
            The value to assign to the schema_drift_config property of this Target.
        :type schema_drift_config: oci.data_integration.models.SchemaDriftConfig

        :param fixed_data_shape:
            The value to assign to the fixed_data_shape property of this Target.
        :type fixed_data_shape: oci.data_integration.models.Shape

        :param write_operation_config:
            The value to assign to the write_operation_config property of this Target.
        :type write_operation_config: oci.data_integration.models.WriteOperationConfig

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'description': 'str',
            'object_version': 'int',
            'input_ports': 'list[InputPort]',
            'output_ports': 'list[OutputPort]',
            'object_status': 'int',
            'identifier': 'str',
            'parameters': 'list[Parameter]',
            'op_config_values': 'ConfigValues',
            'entity': 'DataEntity',
            'is_read_access': 'bool',
            'is_copy_fields': 'bool',
            'is_predefined_shape': 'bool',
            'data_property': 'str',
            'schema_drift_config': 'SchemaDriftConfig',
            'fixed_data_shape': 'Shape',
            'write_operation_config': 'WriteOperationConfig'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'description': 'description',
            'object_version': 'objectVersion',
            'input_ports': 'inputPorts',
            'output_ports': 'outputPorts',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'parameters': 'parameters',
            'op_config_values': 'opConfigValues',
            'entity': 'entity',
            'is_read_access': 'isReadAccess',
            'is_copy_fields': 'isCopyFields',
            'is_predefined_shape': 'isPredefinedShape',
            'data_property': 'dataProperty',
            'schema_drift_config': 'schemaDriftConfig',
            'fixed_data_shape': 'fixedDataShape',
            'write_operation_config': 'writeOperationConfig'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._description = None
        self._object_version = None
        self._input_ports = None
        self._output_ports = None
        self._object_status = None
        self._identifier = None
        self._parameters = None
        self._op_config_values = None
        self._entity = None
        self._is_read_access = None
        self._is_copy_fields = None
        self._is_predefined_shape = None
        self._data_property = None
        self._schema_drift_config = None
        self._fixed_data_shape = None
        self._write_operation_config = None
        self._model_type = 'TARGET_OPERATOR'

    @property
    def entity(self):
        """
        Gets the entity of this Target.

        :return: The entity of this Target.
        :rtype: oci.data_integration.models.DataEntity
        """
        return self._entity

    @entity.setter
    def entity(self, entity):
        """
        Sets the entity of this Target.

        :param entity: The entity of this Target.
        :type: oci.data_integration.models.DataEntity
        """
        self._entity = entity

    @property
    def is_read_access(self):
        """
        Gets the is_read_access of this Target.
        Specifies the read access.


        :return: The is_read_access of this Target.
        :rtype: bool
        """
        return self._is_read_access

    @is_read_access.setter
    def is_read_access(self, is_read_access):
        """
        Sets the is_read_access of this Target.
        Specifies the read access.


        :param is_read_access: The is_read_access of this Target.
        :type: bool
        """
        self._is_read_access = is_read_access

    @property
    def is_copy_fields(self):
        """
        Gets the is_copy_fields of this Target.
        Specifies the copy fields.


        :return: The is_copy_fields of this Target.
        :rtype: bool
        """
        return self._is_copy_fields

    @is_copy_fields.setter
    def is_copy_fields(self, is_copy_fields):
        """
        Sets the is_copy_fields of this Target.
        Specifies the copy fields.


        :param is_copy_fields: The is_copy_fields of this Target.
        :type: bool
        """
        self._is_copy_fields = is_copy_fields

    @property
    def is_predefined_shape(self):
        """
        Gets the is_predefined_shape of this Target.
        Specifies if this uses a predefined shape.


        :return: The is_predefined_shape of this Target.
        :rtype: bool
        """
        return self._is_predefined_shape

    @is_predefined_shape.setter
    def is_predefined_shape(self, is_predefined_shape):
        """
        Sets the is_predefined_shape of this Target.
        Specifies if this uses a predefined shape.


        :param is_predefined_shape: The is_predefined_shape of this Target.
        :type: bool
        """
        self._is_predefined_shape = is_predefined_shape

    @property
    def data_property(self):
        """
        Gets the data_property of this Target.
        Specifies the data property.

        Allowed values for this property are: "TRUNCATE", "MERGE", "BACKUP", "OVERWRITE", "APPEND", "IGNORE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The data_property of this Target.
        :rtype: str
        """
        return self._data_property

    @data_property.setter
    def data_property(self, data_property):
        """
        Sets the data_property of this Target.
        Specifies the data property.


        :param data_property: The data_property of this Target.
        :type: str
        """
        allowed_values = ["TRUNCATE", "MERGE", "BACKUP", "OVERWRITE", "APPEND", "IGNORE"]
        if not value_allowed_none_or_none_sentinel(data_property, allowed_values):
            data_property = 'UNKNOWN_ENUM_VALUE'
        self._data_property = data_property

    @property
    def schema_drift_config(self):
        """
        Gets the schema_drift_config of this Target.

        :return: The schema_drift_config of this Target.
        :rtype: oci.data_integration.models.SchemaDriftConfig
        """
        return self._schema_drift_config

    @schema_drift_config.setter
    def schema_drift_config(self, schema_drift_config):
        """
        Sets the schema_drift_config of this Target.

        :param schema_drift_config: The schema_drift_config of this Target.
        :type: oci.data_integration.models.SchemaDriftConfig
        """
        self._schema_drift_config = schema_drift_config

    @property
    def fixed_data_shape(self):
        """
        Gets the fixed_data_shape of this Target.

        :return: The fixed_data_shape of this Target.
        :rtype: oci.data_integration.models.Shape
        """
        return self._fixed_data_shape

    @fixed_data_shape.setter
    def fixed_data_shape(self, fixed_data_shape):
        """
        Sets the fixed_data_shape of this Target.

        :param fixed_data_shape: The fixed_data_shape of this Target.
        :type: oci.data_integration.models.Shape
        """
        self._fixed_data_shape = fixed_data_shape

    @property
    def write_operation_config(self):
        """
        Gets the write_operation_config of this Target.

        :return: The write_operation_config of this Target.
        :rtype: oci.data_integration.models.WriteOperationConfig
        """
        return self._write_operation_config

    @write_operation_config.setter
    def write_operation_config(self, write_operation_config):
        """
        Sets the write_operation_config of this Target.

        :param write_operation_config: The write_operation_config of this Target.
        :type: oci.data_integration.models.WriteOperationConfig
        """
        self._write_operation_config = write_operation_config

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PreauthenticatedRequest(object):
    """
    Pre-authenticated requests provide a way to let users access a bucket or an object without having their own credentials.
    When you create a pre-authenticated request, a unique URL is generated. Users in your organization, partners, or third
    parties can use this URL to access the targets identified in the pre-authenticated request.
    See `Using Pre-Authenticated Requests`__.

    To use any of the API operations, you must be authorized in an IAM policy. If you are not authorized, talk to an
    administrator. If you are an administrator who needs to write policies to give users access, see
    `Getting Started with Policies`__.

    __ https://docs.cloud.oracle.com/Content/Object/Tasks/usingpreauthenticatedrequests.htm
    __ https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm
    """

    #: A constant which can be used with the bucket_listing_action property of a PreauthenticatedRequest.
    #: This constant has a value of "Deny"
    BUCKET_LISTING_ACTION_DENY = "Deny"

    #: A constant which can be used with the bucket_listing_action property of a PreauthenticatedRequest.
    #: This constant has a value of "ListObjects"
    BUCKET_LISTING_ACTION_LIST_OBJECTS = "ListObjects"

    #: A constant which can be used with the access_type property of a PreauthenticatedRequest.
    #: This constant has a value of "ObjectRead"
    ACCESS_TYPE_OBJECT_READ = "ObjectRead"

    #: A constant which can be used with the access_type property of a PreauthenticatedRequest.
    #: This constant has a value of "ObjectWrite"
    ACCESS_TYPE_OBJECT_WRITE = "ObjectWrite"

    #: A constant which can be used with the access_type property of a PreauthenticatedRequest.
    #: This constant has a value of "ObjectReadWrite"
    ACCESS_TYPE_OBJECT_READ_WRITE = "ObjectReadWrite"

    #: A constant which can be used with the access_type property of a PreauthenticatedRequest.
    #: This constant has a value of "AnyObjectWrite"
    ACCESS_TYPE_ANY_OBJECT_WRITE = "AnyObjectWrite"

    #: A constant which can be used with the access_type property of a PreauthenticatedRequest.
    #: This constant has a value of "AnyObjectRead"
    ACCESS_TYPE_ANY_OBJECT_READ = "AnyObjectRead"

    #: A constant which can be used with the access_type property of a PreauthenticatedRequest.
    #: This constant has a value of "AnyObjectReadWrite"
    ACCESS_TYPE_ANY_OBJECT_READ_WRITE = "AnyObjectReadWrite"

    def __init__(self, **kwargs):
        """
        Initializes a new PreauthenticatedRequest object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this PreauthenticatedRequest.
        :type id: str

        :param name:
            The value to assign to the name property of this PreauthenticatedRequest.
        :type name: str

        :param access_uri:
            The value to assign to the access_uri property of this PreauthenticatedRequest.
        :type access_uri: str

        :param object_name:
            The value to assign to the object_name property of this PreauthenticatedRequest.
        :type object_name: str

        :param bucket_listing_action:
            The value to assign to the bucket_listing_action property of this PreauthenticatedRequest.
            Allowed values for this property are: "Deny", "ListObjects", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type bucket_listing_action: str

        :param access_type:
            The value to assign to the access_type property of this PreauthenticatedRequest.
            Allowed values for this property are: "ObjectRead", "ObjectWrite", "ObjectReadWrite", "AnyObjectWrite", "AnyObjectRead", "AnyObjectReadWrite", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type access_type: str

        :param time_expires:
            The value to assign to the time_expires property of this PreauthenticatedRequest.
        :type time_expires: datetime

        :param time_created:
            The value to assign to the time_created property of this PreauthenticatedRequest.
        :type time_created: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'access_uri': 'str',
            'object_name': 'str',
            'bucket_listing_action': 'str',
            'access_type': 'str',
            'time_expires': 'datetime',
            'time_created': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'access_uri': 'accessUri',
            'object_name': 'objectName',
            'bucket_listing_action': 'bucketListingAction',
            'access_type': 'accessType',
            'time_expires': 'timeExpires',
            'time_created': 'timeCreated'
        }

        self._id = None
        self._name = None
        self._access_uri = None
        self._object_name = None
        self._bucket_listing_action = None
        self._access_type = None
        self._time_expires = None
        self._time_created = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this PreauthenticatedRequest.
        The unique identifier to use when directly addressing the pre-authenticated request.


        :return: The id of this PreauthenticatedRequest.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this PreauthenticatedRequest.
        The unique identifier to use when directly addressing the pre-authenticated request.


        :param id: The id of this PreauthenticatedRequest.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this PreauthenticatedRequest.
        The user-provided name of the pre-authenticated request.


        :return: The name of this PreauthenticatedRequest.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this PreauthenticatedRequest.
        The user-provided name of the pre-authenticated request.


        :param name: The name of this PreauthenticatedRequest.
        :type: str
        """
        self._name = name

    @property
    def access_uri(self):
        """
        **[Required]** Gets the access_uri of this PreauthenticatedRequest.
        The URI to embed in the URL when using the pre-authenticated request.


        :return: The access_uri of this PreauthenticatedRequest.
        :rtype: str
        """
        return self._access_uri

    @access_uri.setter
    def access_uri(self, access_uri):
        """
        Sets the access_uri of this PreauthenticatedRequest.
        The URI to embed in the URL when using the pre-authenticated request.


        :param access_uri: The access_uri of this PreauthenticatedRequest.
        :type: str
        """
        self._access_uri = access_uri

    @property
    def object_name(self):
        """
        Gets the object_name of this PreauthenticatedRequest.
        The name of the object that is being granted access to by the pre-authenticated request. Avoid entering confidential
        information. The object name can be null and if so, the pre-authenticated request grants access to the entire bucket.
        Example: test/object1.log


        :return: The object_name of this PreauthenticatedRequest.
        :rtype: str
        """
        return self._object_name

    @object_name.setter
    def object_name(self, object_name):
        """
        Sets the object_name of this PreauthenticatedRequest.
        The name of the object that is being granted access to by the pre-authenticated request. Avoid entering confidential
        information. The object name can be null and if so, the pre-authenticated request grants access to the entire bucket.
        Example: test/object1.log


        :param object_name: The object_name of this PreauthenticatedRequest.
        :type: str
        """
        self._object_name = object_name

    @property
    def bucket_listing_action(self):
        """
        Gets the bucket_listing_action of this PreauthenticatedRequest.
        Specifies whether a list operation is allowed on a PAR with accessType \"AnyObjectRead\" or \"AnyObjectReadWrite\".
        Deny: Prevents the user from performing a list operation.
        ListObjects: Authorizes the user to perform a list operation.

        Allowed values for this property are: "Deny", "ListObjects", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The bucket_listing_action of this PreauthenticatedRequest.
        :rtype: str
        """
        return self._bucket_listing_action

    @bucket_listing_action.setter
    def bucket_listing_action(self, bucket_listing_action):
        """
        Sets the bucket_listing_action of this PreauthenticatedRequest.
        Specifies whether a list operation is allowed on a PAR with accessType \"AnyObjectRead\" or \"AnyObjectReadWrite\".
        Deny: Prevents the user from performing a list operation.
        ListObjects: Authorizes the user to perform a list operation.


        :param bucket_listing_action: The bucket_listing_action of this PreauthenticatedRequest.
        :type: str
        """
        allowed_values = ["Deny", "ListObjects"]
        if not value_allowed_none_or_none_sentinel(bucket_listing_action, allowed_values):
            bucket_listing_action = 'UNKNOWN_ENUM_VALUE'
        self._bucket_listing_action = bucket_listing_action

    @property
    def access_type(self):
        """
        **[Required]** Gets the access_type of this PreauthenticatedRequest.
        The operation that can be performed on this resource.

        Allowed values for this property are: "ObjectRead", "ObjectWrite", "ObjectReadWrite", "AnyObjectWrite", "AnyObjectRead", "AnyObjectReadWrite", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The access_type of this PreauthenticatedRequest.
        :rtype: str
        """
        return self._access_type

    @access_type.setter
    def access_type(self, access_type):
        """
        Sets the access_type of this PreauthenticatedRequest.
        The operation that can be performed on this resource.


        :param access_type: The access_type of this PreauthenticatedRequest.
        :type: str
        """
        allowed_values = ["ObjectRead", "ObjectWrite", "ObjectReadWrite", "AnyObjectWrite", "AnyObjectRead", "AnyObjectReadWrite"]
        if not value_allowed_none_or_none_sentinel(access_type, allowed_values):
            access_type = 'UNKNOWN_ENUM_VALUE'
        self._access_type = access_type

    @property
    def time_expires(self):
        """
        **[Required]** Gets the time_expires of this PreauthenticatedRequest.
        The expiration date for the pre-authenticated request as per `RFC 3339`__. After
        this date the pre-authenticated request will no longer be valid.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_expires of this PreauthenticatedRequest.
        :rtype: datetime
        """
        return self._time_expires

    @time_expires.setter
    def time_expires(self, time_expires):
        """
        Sets the time_expires of this PreauthenticatedRequest.
        The expiration date for the pre-authenticated request as per `RFC 3339`__. After
        this date the pre-authenticated request will no longer be valid.

        __ https://tools.ietf.org/html/rfc3339


        :param time_expires: The time_expires of this PreauthenticatedRequest.
        :type: datetime
        """
        self._time_expires = time_expires

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this PreauthenticatedRequest.
        The date when the pre-authenticated request was created as per specification
        `RFC 3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this PreauthenticatedRequest.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this PreauthenticatedRequest.
        The date when the pre-authenticated request was created as per specification
        `RFC 3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this PreauthenticatedRequest.
        :type: datetime
        """
        self._time_created = time_created

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AwrDbSysstatSummary(object):
    """
    The summary of the AWR SYSSTAT data.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AwrDbSysstatSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this AwrDbSysstatSummary.
        :type name: str

        :param category:
            The value to assign to the category property of this AwrDbSysstatSummary.
        :type category: str

        :param time_begin:
            The value to assign to the time_begin property of this AwrDbSysstatSummary.
        :type time_begin: datetime

        :param time_end:
            The value to assign to the time_end property of this AwrDbSysstatSummary.
        :type time_end: datetime

        :param avg_value:
            The value to assign to the avg_value property of this AwrDbSysstatSummary.
        :type avg_value: float

        :param current_value:
            The value to assign to the current_value property of this AwrDbSysstatSummary.
        :type current_value: float

        """
        self.swagger_types = {
            'name': 'str',
            'category': 'str',
            'time_begin': 'datetime',
            'time_end': 'datetime',
            'avg_value': 'float',
            'current_value': 'float'
        }

        self.attribute_map = {
            'name': 'name',
            'category': 'category',
            'time_begin': 'timeBegin',
            'time_end': 'timeEnd',
            'avg_value': 'avgValue',
            'current_value': 'currentValue'
        }

        self._name = None
        self._category = None
        self._time_begin = None
        self._time_end = None
        self._avg_value = None
        self._current_value = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this AwrDbSysstatSummary.
        The name of the SYSSTAT.


        :return: The name of this AwrDbSysstatSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this AwrDbSysstatSummary.
        The name of the SYSSTAT.


        :param name: The name of this AwrDbSysstatSummary.
        :type: str
        """
        self._name = name

    @property
    def category(self):
        """
        Gets the category of this AwrDbSysstatSummary.
        The name of the SYSSTAT category.


        :return: The category of this AwrDbSysstatSummary.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this AwrDbSysstatSummary.
        The name of the SYSSTAT category.


        :param category: The category of this AwrDbSysstatSummary.
        :type: str
        """
        self._category = category

    @property
    def time_begin(self):
        """
        Gets the time_begin of this AwrDbSysstatSummary.
        The start time of the SYSSTAT.


        :return: The time_begin of this AwrDbSysstatSummary.
        :rtype: datetime
        """
        return self._time_begin

    @time_begin.setter
    def time_begin(self, time_begin):
        """
        Sets the time_begin of this AwrDbSysstatSummary.
        The start time of the SYSSTAT.


        :param time_begin: The time_begin of this AwrDbSysstatSummary.
        :type: datetime
        """
        self._time_begin = time_begin

    @property
    def time_end(self):
        """
        Gets the time_end of this AwrDbSysstatSummary.
        The end time of the SYSSTAT.


        :return: The time_end of this AwrDbSysstatSummary.
        :rtype: datetime
        """
        return self._time_end

    @time_end.setter
    def time_end(self, time_end):
        """
        Sets the time_end of this AwrDbSysstatSummary.
        The end time of the SYSSTAT.


        :param time_end: The time_end of this AwrDbSysstatSummary.
        :type: datetime
        """
        self._time_end = time_end

    @property
    def avg_value(self):
        """
        Gets the avg_value of this AwrDbSysstatSummary.
        The average value of the SYSSTAT.


        :return: The avg_value of this AwrDbSysstatSummary.
        :rtype: float
        """
        return self._avg_value

    @avg_value.setter
    def avg_value(self, avg_value):
        """
        Sets the avg_value of this AwrDbSysstatSummary.
        The average value of the SYSSTAT.


        :param avg_value: The avg_value of this AwrDbSysstatSummary.
        :type: float
        """
        self._avg_value = avg_value

    @property
    def current_value(self):
        """
        Gets the current_value of this AwrDbSysstatSummary.
        The last value of the SYSSTAT.


        :return: The current_value of this AwrDbSysstatSummary.
        :rtype: float
        """
        return self._current_value

    @current_value.setter
    def current_value(self, current_value):
        """
        Sets the current_value of this AwrDbSysstatSummary.
        The last value of the SYSSTAT.


        :param current_value: The current_value of this AwrDbSysstatSummary.
        :type: float
        """
        self._current_value = current_value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateImagePolicyConfigDetails(object):
    """
    The properties that define a image verification policy.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateImagePolicyConfigDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_policy_enabled:
            The value to assign to the is_policy_enabled property of this UpdateImagePolicyConfigDetails.
        :type is_policy_enabled: bool

        :param key_details:
            The value to assign to the key_details property of this UpdateImagePolicyConfigDetails.
        :type key_details: list[oci.container_engine.models.KeyDetails]

        """
        self.swagger_types = {
            'is_policy_enabled': 'bool',
            'key_details': 'list[KeyDetails]'
        }

        self.attribute_map = {
            'is_policy_enabled': 'isPolicyEnabled',
            'key_details': 'keyDetails'
        }

        self._is_policy_enabled = None
        self._key_details = None

    @property
    def is_policy_enabled(self):
        """
        Gets the is_policy_enabled of this UpdateImagePolicyConfigDetails.
        Whether the image verification policy is enabled. Defaults to false. If set to true, the images will be verified against the policy at runtime.


        :return: The is_policy_enabled of this UpdateImagePolicyConfigDetails.
        :rtype: bool
        """
        return self._is_policy_enabled

    @is_policy_enabled.setter
    def is_policy_enabled(self, is_policy_enabled):
        """
        Sets the is_policy_enabled of this UpdateImagePolicyConfigDetails.
        Whether the image verification policy is enabled. Defaults to false. If set to true, the images will be verified against the policy at runtime.


        :param is_policy_enabled: The is_policy_enabled of this UpdateImagePolicyConfigDetails.
        :type: bool
        """
        self._is_policy_enabled = is_policy_enabled

    @property
    def key_details(self):
        """
        Gets the key_details of this UpdateImagePolicyConfigDetails.
        A list of KMS key details.


        :return: The key_details of this UpdateImagePolicyConfigDetails.
        :rtype: list[oci.container_engine.models.KeyDetails]
        """
        return self._key_details

    @key_details.setter
    def key_details(self, key_details):
        """
        Sets the key_details of this UpdateImagePolicyConfigDetails.
        A list of KMS key details.


        :param key_details: The key_details of this UpdateImagePolicyConfigDetails.
        :type: list[oci.container_engine.models.KeyDetails]
        """
        self._key_details = key_details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsParserSummary(object):
    """
    LoganParserDetails
    """

    #: A constant which can be used with the type property of a LogAnalyticsParserSummary.
    #: This constant has a value of "XML"
    TYPE_XML = "XML"

    #: A constant which can be used with the type property of a LogAnalyticsParserSummary.
    #: This constant has a value of "JSON"
    TYPE_JSON = "JSON"

    #: A constant which can be used with the type property of a LogAnalyticsParserSummary.
    #: This constant has a value of "REGEX"
    TYPE_REGEX = "REGEX"

    #: A constant which can be used with the type property of a LogAnalyticsParserSummary.
    #: This constant has a value of "ODL"
    TYPE_ODL = "ODL"

    #: A constant which can be used with the type property of a LogAnalyticsParserSummary.
    #: This constant has a value of "DELIMITED"
    TYPE_DELIMITED = "DELIMITED"

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsParserSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param content:
            The value to assign to the content property of this LogAnalyticsParserSummary.
        :type content: str

        :param description:
            The value to assign to the description property of this LogAnalyticsParserSummary.
        :type description: str

        :param display_name:
            The value to assign to the display_name property of this LogAnalyticsParserSummary.
        :type display_name: str

        :param edit_version:
            The value to assign to the edit_version property of this LogAnalyticsParserSummary.
        :type edit_version: int

        :param encoding:
            The value to assign to the encoding property of this LogAnalyticsParserSummary.
        :type encoding: str

        :param example_content:
            The value to assign to the example_content property of this LogAnalyticsParserSummary.
        :type example_content: str

        :param field_maps:
            The value to assign to the field_maps property of this LogAnalyticsParserSummary.
        :type field_maps: list[oci.log_analytics.models.LogAnalyticsParserField]

        :param footer_content:
            The value to assign to the footer_content property of this LogAnalyticsParserSummary.
        :type footer_content: str

        :param header_content:
            The value to assign to the header_content property of this LogAnalyticsParserSummary.
        :type header_content: str

        :param name:
            The value to assign to the name property of this LogAnalyticsParserSummary.
        :type name: str

        :param is_default:
            The value to assign to the is_default property of this LogAnalyticsParserSummary.
        :type is_default: bool

        :param is_single_line_content:
            The value to assign to the is_single_line_content property of this LogAnalyticsParserSummary.
        :type is_single_line_content: bool

        :param is_system:
            The value to assign to the is_system property of this LogAnalyticsParserSummary.
        :type is_system: bool

        :param language:
            The value to assign to the language property of this LogAnalyticsParserSummary.
        :type language: str

        :param time_updated:
            The value to assign to the time_updated property of this LogAnalyticsParserSummary.
        :type time_updated: datetime

        :param log_type_test_request_version:
            The value to assign to the log_type_test_request_version property of this LogAnalyticsParserSummary.
        :type log_type_test_request_version: int

        :param mapped_parsers:
            The value to assign to the mapped_parsers property of this LogAnalyticsParserSummary.
        :type mapped_parsers: list[oci.log_analytics.models.LogAnalyticsParser]

        :param parser_ignoreline_characters:
            The value to assign to the parser_ignoreline_characters property of this LogAnalyticsParserSummary.
        :type parser_ignoreline_characters: str

        :param is_hidden:
            The value to assign to the is_hidden property of this LogAnalyticsParserSummary.
        :type is_hidden: bool

        :param parser_sequence:
            The value to assign to the parser_sequence property of this LogAnalyticsParserSummary.
        :type parser_sequence: int

        :param parser_timezone:
            The value to assign to the parser_timezone property of this LogAnalyticsParserSummary.
        :type parser_timezone: str

        :param parser_filter:
            The value to assign to the parser_filter property of this LogAnalyticsParserSummary.
        :type parser_filter: oci.log_analytics.models.LogAnalyticsParserFilter

        :param is_parser_written_once:
            The value to assign to the is_parser_written_once property of this LogAnalyticsParserSummary.
        :type is_parser_written_once: bool

        :param parser_functions:
            The value to assign to the parser_functions property of this LogAnalyticsParserSummary.
        :type parser_functions: list[oci.log_analytics.models.LogAnalyticsParserFunction]

        :param sources_count:
            The value to assign to the sources_count property of this LogAnalyticsParserSummary.
        :type sources_count: int

        :param sources:
            The value to assign to the sources property of this LogAnalyticsParserSummary.
        :type sources: list[oci.log_analytics.models.LogAnalyticsSource]

        :param should_tokenize_original_text:
            The value to assign to the should_tokenize_original_text property of this LogAnalyticsParserSummary.
        :type should_tokenize_original_text: bool

        :param field_delimiter:
            The value to assign to the field_delimiter property of this LogAnalyticsParserSummary.
        :type field_delimiter: str

        :param field_qualifier:
            The value to assign to the field_qualifier property of this LogAnalyticsParserSummary.
        :type field_qualifier: str

        :param type:
            The value to assign to the type property of this LogAnalyticsParserSummary.
            Allowed values for this property are: "XML", "JSON", "REGEX", "ODL", "DELIMITED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param is_user_deleted:
            The value to assign to the is_user_deleted property of this LogAnalyticsParserSummary.
        :type is_user_deleted: bool

        """
        self.swagger_types = {
            'content': 'str',
            'description': 'str',
            'display_name': 'str',
            'edit_version': 'int',
            'encoding': 'str',
            'example_content': 'str',
            'field_maps': 'list[LogAnalyticsParserField]',
            'footer_content': 'str',
            'header_content': 'str',
            'name': 'str',
            'is_default': 'bool',
            'is_single_line_content': 'bool',
            'is_system': 'bool',
            'language': 'str',
            'time_updated': 'datetime',
            'log_type_test_request_version': 'int',
            'mapped_parsers': 'list[LogAnalyticsParser]',
            'parser_ignoreline_characters': 'str',
            'is_hidden': 'bool',
            'parser_sequence': 'int',
            'parser_timezone': 'str',
            'parser_filter': 'LogAnalyticsParserFilter',
            'is_parser_written_once': 'bool',
            'parser_functions': 'list[LogAnalyticsParserFunction]',
            'sources_count': 'int',
            'sources': 'list[LogAnalyticsSource]',
            'should_tokenize_original_text': 'bool',
            'field_delimiter': 'str',
            'field_qualifier': 'str',
            'type': 'str',
            'is_user_deleted': 'bool'
        }

        self.attribute_map = {
            'content': 'content',
            'description': 'description',
            'display_name': 'displayName',
            'edit_version': 'editVersion',
            'encoding': 'encoding',
            'example_content': 'exampleContent',
            'field_maps': 'fieldMaps',
            'footer_content': 'footerContent',
            'header_content': 'headerContent',
            'name': 'name',
            'is_default': 'isDefault',
            'is_single_line_content': 'isSingleLineContent',
            'is_system': 'isSystem',
            'language': 'language',
            'time_updated': 'timeUpdated',
            'log_type_test_request_version': 'logTypeTestRequestVersion',
            'mapped_parsers': 'mappedParsers',
            'parser_ignoreline_characters': 'parserIgnorelineCharacters',
            'is_hidden': 'isHidden',
            'parser_sequence': 'parserSequence',
            'parser_timezone': 'parserTimezone',
            'parser_filter': 'parserFilter',
            'is_parser_written_once': 'isParserWrittenOnce',
            'parser_functions': 'parserFunctions',
            'sources_count': 'sourcesCount',
            'sources': 'sources',
            'should_tokenize_original_text': 'shouldTokenizeOriginalText',
            'field_delimiter': 'fieldDelimiter',
            'field_qualifier': 'fieldQualifier',
            'type': 'type',
            'is_user_deleted': 'isUserDeleted'
        }

        self._content = None
        self._description = None
        self._display_name = None
        self._edit_version = None
        self._encoding = None
        self._example_content = None
        self._field_maps = None
        self._footer_content = None
        self._header_content = None
        self._name = None
        self._is_default = None
        self._is_single_line_content = None
        self._is_system = None
        self._language = None
        self._time_updated = None
        self._log_type_test_request_version = None
        self._mapped_parsers = None
        self._parser_ignoreline_characters = None
        self._is_hidden = None
        self._parser_sequence = None
        self._parser_timezone = None
        self._parser_filter = None
        self._is_parser_written_once = None
        self._parser_functions = None
        self._sources_count = None
        self._sources = None
        self._should_tokenize_original_text = None
        self._field_delimiter = None
        self._field_qualifier = None
        self._type = None
        self._is_user_deleted = None

    @property
    def content(self):
        """
        Gets the content of this LogAnalyticsParserSummary.
        The content.


        :return: The content of this LogAnalyticsParserSummary.
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """
        Sets the content of this LogAnalyticsParserSummary.
        The content.


        :param content: The content of this LogAnalyticsParserSummary.
        :type: str
        """
        self._content = content

    @property
    def description(self):
        """
        Gets the description of this LogAnalyticsParserSummary.
        The parser description.


        :return: The description of this LogAnalyticsParserSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this LogAnalyticsParserSummary.
        The parser description.


        :param description: The description of this LogAnalyticsParserSummary.
        :type: str
        """
        self._description = description

    @property
    def display_name(self):
        """
        Gets the display_name of this LogAnalyticsParserSummary.
        The parser display name.


        :return: The display_name of this LogAnalyticsParserSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this LogAnalyticsParserSummary.
        The parser display name.


        :param display_name: The display_name of this LogAnalyticsParserSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def edit_version(self):
        """
        Gets the edit_version of this LogAnalyticsParserSummary.
        The parser edit version.


        :return: The edit_version of this LogAnalyticsParserSummary.
        :rtype: int
        """
        return self._edit_version

    @edit_version.setter
    def edit_version(self, edit_version):
        """
        Sets the edit_version of this LogAnalyticsParserSummary.
        The parser edit version.


        :param edit_version: The edit_version of this LogAnalyticsParserSummary.
        :type: int
        """
        self._edit_version = edit_version

    @property
    def encoding(self):
        """
        Gets the encoding of this LogAnalyticsParserSummary.
        The encoding.


        :return: The encoding of this LogAnalyticsParserSummary.
        :rtype: str
        """
        return self._encoding

    @encoding.setter
    def encoding(self, encoding):
        """
        Sets the encoding of this LogAnalyticsParserSummary.
        The encoding.


        :param encoding: The encoding of this LogAnalyticsParserSummary.
        :type: str
        """
        self._encoding = encoding

    @property
    def example_content(self):
        """
        Gets the example_content of this LogAnalyticsParserSummary.
        The example content.


        :return: The example_content of this LogAnalyticsParserSummary.
        :rtype: str
        """
        return self._example_content

    @example_content.setter
    def example_content(self, example_content):
        """
        Sets the example_content of this LogAnalyticsParserSummary.
        The example content.


        :param example_content: The example_content of this LogAnalyticsParserSummary.
        :type: str
        """
        self._example_content = example_content

    @property
    def field_maps(self):
        """
        Gets the field_maps of this LogAnalyticsParserSummary.
        The parser fields.


        :return: The field_maps of this LogAnalyticsParserSummary.
        :rtype: list[oci.log_analytics.models.LogAnalyticsParserField]
        """
        return self._field_maps

    @field_maps.setter
    def field_maps(self, field_maps):
        """
        Sets the field_maps of this LogAnalyticsParserSummary.
        The parser fields.


        :param field_maps: The field_maps of this LogAnalyticsParserSummary.
        :type: list[oci.log_analytics.models.LogAnalyticsParserField]
        """
        self._field_maps = field_maps

    @property
    def footer_content(self):
        """
        Gets the footer_content of this LogAnalyticsParserSummary.
        The footer regular expression.


        :return: The footer_content of this LogAnalyticsParserSummary.
        :rtype: str
        """
        return self._footer_content

    @footer_content.setter
    def footer_content(self, footer_content):
        """
        Sets the footer_content of this LogAnalyticsParserSummary.
        The footer regular expression.


        :param footer_content: The footer_content of this LogAnalyticsParserSummary.
        :type: str
        """
        self._footer_content = footer_content

    @property
    def header_content(self):
        """
        Gets the header_content of this LogAnalyticsParserSummary.
        The header content.


        :return: The header_content of this LogAnalyticsParserSummary.
        :rtype: str
        """
        return self._header_content

    @header_content.setter
    def header_content(self, header_content):
        """
        Sets the header_content of this LogAnalyticsParserSummary.
        The header content.


        :param header_content: The header_content of this LogAnalyticsParserSummary.
        :type: str
        """
        self._header_content = header_content

    @property
    def name(self):
        """
        Gets the name of this LogAnalyticsParserSummary.
        The parser name.


        :return: The name of this LogAnalyticsParserSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this LogAnalyticsParserSummary.
        The parser name.


        :param name: The name of this LogAnalyticsParserSummary.
        :type: str
        """
        self._name = name

    @property
    def is_default(self):
        """
        Gets the is_default of this LogAnalyticsParserSummary.
        A flag indicating if this is a default parser.


        :return: The is_default of this LogAnalyticsParserSummary.
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """
        Sets the is_default of this LogAnalyticsParserSummary.
        A flag indicating if this is a default parser.


        :param is_default: The is_default of this LogAnalyticsParserSummary.
        :type: bool
        """
        self._is_default = is_default

    @property
    def is_single_line_content(self):
        """
        Gets the is_single_line_content of this LogAnalyticsParserSummary.
        A flag indicating if this is a single line content parser.


        :return: The is_single_line_content of this LogAnalyticsParserSummary.
        :rtype: bool
        """
        return self._is_single_line_content

    @is_single_line_content.setter
    def is_single_line_content(self, is_single_line_content):
        """
        Sets the is_single_line_content of this LogAnalyticsParserSummary.
        A flag indicating if this is a single line content parser.


        :param is_single_line_content: The is_single_line_content of this LogAnalyticsParserSummary.
        :type: bool
        """
        self._is_single_line_content = is_single_line_content

    @property
    def is_system(self):
        """
        Gets the is_system of this LogAnalyticsParserSummary.
        The system flag.  A value of false denotes a custom, or user
        defined object.  A value of true denotes a built in object.


        :return: The is_system of this LogAnalyticsParserSummary.
        :rtype: bool
        """
        return self._is_system

    @is_system.setter
    def is_system(self, is_system):
        """
        Sets the is_system of this LogAnalyticsParserSummary.
        The system flag.  A value of false denotes a custom, or user
        defined object.  A value of true denotes a built in object.


        :param is_system: The is_system of this LogAnalyticsParserSummary.
        :type: bool
        """
        self._is_system = is_system

    @property
    def language(self):
        """
        Gets the language of this LogAnalyticsParserSummary.
        The language.


        :return: The language of this LogAnalyticsParserSummary.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """
        Sets the language of this LogAnalyticsParserSummary.
        The language.


        :param language: The language of this LogAnalyticsParserSummary.
        :type: str
        """
        self._language = language

    @property
    def time_updated(self):
        """
        Gets the time_updated of this LogAnalyticsParserSummary.
        The last updated date.


        :return: The time_updated of this LogAnalyticsParserSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this LogAnalyticsParserSummary.
        The last updated date.


        :param time_updated: The time_updated of this LogAnalyticsParserSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def log_type_test_request_version(self):
        """
        Gets the log_type_test_request_version of this LogAnalyticsParserSummary.
        The log type test request version.


        :return: The log_type_test_request_version of this LogAnalyticsParserSummary.
        :rtype: int
        """
        return self._log_type_test_request_version

    @log_type_test_request_version.setter
    def log_type_test_request_version(self, log_type_test_request_version):
        """
        Sets the log_type_test_request_version of this LogAnalyticsParserSummary.
        The log type test request version.


        :param log_type_test_request_version: The log_type_test_request_version of this LogAnalyticsParserSummary.
        :type: int
        """
        self._log_type_test_request_version = log_type_test_request_version

    @property
    def mapped_parsers(self):
        """
        Gets the mapped_parsers of this LogAnalyticsParserSummary.
        The mapped parser list.


        :return: The mapped_parsers of this LogAnalyticsParserSummary.
        :rtype: list[oci.log_analytics.models.LogAnalyticsParser]
        """
        return self._mapped_parsers

    @mapped_parsers.setter
    def mapped_parsers(self, mapped_parsers):
        """
        Sets the mapped_parsers of this LogAnalyticsParserSummary.
        The mapped parser list.


        :param mapped_parsers: The mapped_parsers of this LogAnalyticsParserSummary.
        :type: list[oci.log_analytics.models.LogAnalyticsParser]
        """
        self._mapped_parsers = mapped_parsers

    @property
    def parser_ignoreline_characters(self):
        """
        Gets the parser_ignoreline_characters of this LogAnalyticsParserSummary.
        The line characters for the parser to ignore.


        :return: The parser_ignoreline_characters of this LogAnalyticsParserSummary.
        :rtype: str
        """
        return self._parser_ignoreline_characters

    @parser_ignoreline_characters.setter
    def parser_ignoreline_characters(self, parser_ignoreline_characters):
        """
        Sets the parser_ignoreline_characters of this LogAnalyticsParserSummary.
        The line characters for the parser to ignore.


        :param parser_ignoreline_characters: The parser_ignoreline_characters of this LogAnalyticsParserSummary.
        :type: str
        """
        self._parser_ignoreline_characters = parser_ignoreline_characters

    @property
    def is_hidden(self):
        """
        Gets the is_hidden of this LogAnalyticsParserSummary.
        A flag indicating if the parser is hidden or not.


        :return: The is_hidden of this LogAnalyticsParserSummary.
        :rtype: bool
        """
        return self._is_hidden

    @is_hidden.setter
    def is_hidden(self, is_hidden):
        """
        Sets the is_hidden of this LogAnalyticsParserSummary.
        A flag indicating if the parser is hidden or not.


        :param is_hidden: The is_hidden of this LogAnalyticsParserSummary.
        :type: bool
        """
        self._is_hidden = is_hidden

    @property
    def parser_sequence(self):
        """
        Gets the parser_sequence of this LogAnalyticsParserSummary.
        The parser sequence.


        :return: The parser_sequence of this LogAnalyticsParserSummary.
        :rtype: int
        """
        return self._parser_sequence

    @parser_sequence.setter
    def parser_sequence(self, parser_sequence):
        """
        Sets the parser_sequence of this LogAnalyticsParserSummary.
        The parser sequence.


        :param parser_sequence: The parser_sequence of this LogAnalyticsParserSummary.
        :type: int
        """
        self._parser_sequence = parser_sequence

    @property
    def parser_timezone(self):
        """
        Gets the parser_timezone of this LogAnalyticsParserSummary.
        The time zone.


        :return: The parser_timezone of this LogAnalyticsParserSummary.
        :rtype: str
        """
        return self._parser_timezone

    @parser_timezone.setter
    def parser_timezone(self, parser_timezone):
        """
        Sets the parser_timezone of this LogAnalyticsParserSummary.
        The time zone.


        :param parser_timezone: The parser_timezone of this LogAnalyticsParserSummary.
        :type: str
        """
        self._parser_timezone = parser_timezone

    @property
    def parser_filter(self):
        """
        Gets the parser_filter of this LogAnalyticsParserSummary.

        :return: The parser_filter of this LogAnalyticsParserSummary.
        :rtype: oci.log_analytics.models.LogAnalyticsParserFilter
        """
        return self._parser_filter

    @parser_filter.setter
    def parser_filter(self, parser_filter):
        """
        Sets the parser_filter of this LogAnalyticsParserSummary.

        :param parser_filter: The parser_filter of this LogAnalyticsParserSummary.
        :type: oci.log_analytics.models.LogAnalyticsParserFilter
        """
        self._parser_filter = parser_filter

    @property
    def is_parser_written_once(self):
        """
        Gets the is_parser_written_once of this LogAnalyticsParserSummary.
        A flag indicating whther or not the parser is write once.


        :return: The is_parser_written_once of this LogAnalyticsParserSummary.
        :rtype: bool
        """
        return self._is_parser_written_once

    @is_parser_written_once.setter
    def is_parser_written_once(self, is_parser_written_once):
        """
        Sets the is_parser_written_once of this LogAnalyticsParserSummary.
        A flag indicating whther or not the parser is write once.


        :param is_parser_written_once: The is_parser_written_once of this LogAnalyticsParserSummary.
        :type: bool
        """
        self._is_parser_written_once = is_parser_written_once

    @property
    def parser_functions(self):
        """
        Gets the parser_functions of this LogAnalyticsParserSummary.
        The parser function list.


        :return: The parser_functions of this LogAnalyticsParserSummary.
        :rtype: list[oci.log_analytics.models.LogAnalyticsParserFunction]
        """
        return self._parser_functions

    @parser_functions.setter
    def parser_functions(self, parser_functions):
        """
        Sets the parser_functions of this LogAnalyticsParserSummary.
        The parser function list.


        :param parser_functions: The parser_functions of this LogAnalyticsParserSummary.
        :type: list[oci.log_analytics.models.LogAnalyticsParserFunction]
        """
        self._parser_functions = parser_functions

    @property
    def sources_count(self):
        """
        Gets the sources_count of this LogAnalyticsParserSummary.
        The number of sources using this parser.


        :return: The sources_count of this LogAnalyticsParserSummary.
        :rtype: int
        """
        return self._sources_count

    @sources_count.setter
    def sources_count(self, sources_count):
        """
        Sets the sources_count of this LogAnalyticsParserSummary.
        The number of sources using this parser.


        :param sources_count: The sources_count of this LogAnalyticsParserSummary.
        :type: int
        """
        self._sources_count = sources_count

    @property
    def sources(self):
        """
        Gets the sources of this LogAnalyticsParserSummary.
        The list of sources using this parser.


        :return: The sources of this LogAnalyticsParserSummary.
        :rtype: list[oci.log_analytics.models.LogAnalyticsSource]
        """
        return self._sources

    @sources.setter
    def sources(self, sources):
        """
        Sets the sources of this LogAnalyticsParserSummary.
        The list of sources using this parser.


        :param sources: The sources of this LogAnalyticsParserSummary.
        :type: list[oci.log_analytics.models.LogAnalyticsSource]
        """
        self._sources = sources

    @property
    def should_tokenize_original_text(self):
        """
        Gets the should_tokenize_original_text of this LogAnalyticsParserSummary.
        A flag indicating whether or not to tokenize the original text.


        :return: The should_tokenize_original_text of this LogAnalyticsParserSummary.
        :rtype: bool
        """
        return self._should_tokenize_original_text

    @should_tokenize_original_text.setter
    def should_tokenize_original_text(self, should_tokenize_original_text):
        """
        Sets the should_tokenize_original_text of this LogAnalyticsParserSummary.
        A flag indicating whether or not to tokenize the original text.


        :param should_tokenize_original_text: The should_tokenize_original_text of this LogAnalyticsParserSummary.
        :type: bool
        """
        self._should_tokenize_original_text = should_tokenize_original_text

    @property
    def field_delimiter(self):
        """
        Gets the field_delimiter of this LogAnalyticsParserSummary.
        The parser field delimiter.


        :return: The field_delimiter of this LogAnalyticsParserSummary.
        :rtype: str
        """
        return self._field_delimiter

    @field_delimiter.setter
    def field_delimiter(self, field_delimiter):
        """
        Sets the field_delimiter of this LogAnalyticsParserSummary.
        The parser field delimiter.


        :param field_delimiter: The field_delimiter of this LogAnalyticsParserSummary.
        :type: str
        """
        self._field_delimiter = field_delimiter

    @property
    def field_qualifier(self):
        """
        Gets the field_qualifier of this LogAnalyticsParserSummary.
        The parser field qualifier.


        :return: The field_qualifier of this LogAnalyticsParserSummary.
        :rtype: str
        """
        return self._field_qualifier

    @field_qualifier.setter
    def field_qualifier(self, field_qualifier):
        """
        Sets the field_qualifier of this LogAnalyticsParserSummary.
        The parser field qualifier.


        :param field_qualifier: The field_qualifier of this LogAnalyticsParserSummary.
        :type: str
        """
        self._field_qualifier = field_qualifier

    @property
    def type(self):
        """
        Gets the type of this LogAnalyticsParserSummary.
        The parser type.  Default value is REGEX.

        Allowed values for this property are: "XML", "JSON", "REGEX", "ODL", "DELIMITED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this LogAnalyticsParserSummary.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this LogAnalyticsParserSummary.
        The parser type.  Default value is REGEX.


        :param type: The type of this LogAnalyticsParserSummary.
        :type: str
        """
        allowed_values = ["XML", "JSON", "REGEX", "ODL", "DELIMITED"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def is_user_deleted(self):
        """
        Gets the is_user_deleted of this LogAnalyticsParserSummary.
        A flag indicating whether or not the parser has been deleted.


        :return: The is_user_deleted of this LogAnalyticsParserSummary.
        :rtype: bool
        """
        return self._is_user_deleted

    @is_user_deleted.setter
    def is_user_deleted(self, is_user_deleted):
        """
        Sets the is_user_deleted of this LogAnalyticsParserSummary.
        A flag indicating whether or not the parser has been deleted.


        :param is_user_deleted: The is_user_deleted of this LogAnalyticsParserSummary.
        :type: bool
        """
        self._is_user_deleted = is_user_deleted

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .dynamic_type_handler import DynamicTypeHandler
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RuleTypeConfig(DynamicTypeHandler):
    """
    The rule type config.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RuleTypeConfig object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.RuleTypeConfig.model_type` attribute
        of this class is ``RULE_TYPE_CONFIGS`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this RuleTypeConfig.
            Allowed values for this property are: "RULE_TYPE_CONFIGS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type model_type: str

        :param key:
            The value to assign to the key property of this RuleTypeConfig.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this RuleTypeConfig.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this RuleTypeConfig.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param scope:
            The value to assign to the scope property of this RuleTypeConfig.
        :type scope: object

        :param is_order_by_rule:
            The value to assign to the is_order_by_rule property of this RuleTypeConfig.
        :type is_order_by_rule: bool

        :param projection_rules:
            The value to assign to the projection_rules property of this RuleTypeConfig.
        :type projection_rules: list[oci.data_integration.models.ProjectionRule]

        :param config_values:
            The value to assign to the config_values property of this RuleTypeConfig.
        :type config_values: oci.data_integration.models.ConfigValues

        :param object_status:
            The value to assign to the object_status property of this RuleTypeConfig.
        :type object_status: int

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'scope': 'object',
            'is_order_by_rule': 'bool',
            'projection_rules': 'list[ProjectionRule]',
            'config_values': 'ConfigValues',
            'object_status': 'int'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'scope': 'scope',
            'is_order_by_rule': 'isOrderByRule',
            'projection_rules': 'projectionRules',
            'config_values': 'configValues',
            'object_status': 'objectStatus'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._scope = None
        self._is_order_by_rule = None
        self._projection_rules = None
        self._config_values = None
        self._object_status = None
        self._model_type = 'RULE_TYPE_CONFIGS'

    @property
    def key(self):
        """
        Gets the key of this RuleTypeConfig.
        The key of the object.


        :return: The key of this RuleTypeConfig.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this RuleTypeConfig.
        The key of the object.


        :param key: The key of this RuleTypeConfig.
        :type: str
        """
        self._key = key

    @property
    def model_version(self):
        """
        Gets the model_version of this RuleTypeConfig.
        The model version of an object.


        :return: The model_version of this RuleTypeConfig.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this RuleTypeConfig.
        The model version of an object.


        :param model_version: The model_version of this RuleTypeConfig.
        :type: str
        """
        self._model_version = model_version

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this RuleTypeConfig.

        :return: The parent_ref of this RuleTypeConfig.
        :rtype: oci.data_integration.models.ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this RuleTypeConfig.

        :param parent_ref: The parent_ref of this RuleTypeConfig.
        :type: oci.data_integration.models.ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def scope(self):
        """
        Gets the scope of this RuleTypeConfig.
        Reference to a typed object, this can be either a key value to an object within the document, a shall referenced to a `TypedObject` or a full `TypedObject` definition.


        :return: The scope of this RuleTypeConfig.
        :rtype: object
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """
        Sets the scope of this RuleTypeConfig.
        Reference to a typed object, this can be either a key value to an object within the document, a shall referenced to a `TypedObject` or a full `TypedObject` definition.


        :param scope: The scope of this RuleTypeConfig.
        :type: object
        """
        self._scope = scope

    @property
    def is_order_by_rule(self):
        """
        Gets the is_order_by_rule of this RuleTypeConfig.
        Specifies whether it is ordered by rule.


        :return: The is_order_by_rule of this RuleTypeConfig.
        :rtype: bool
        """
        return self._is_order_by_rule

    @is_order_by_rule.setter
    def is_order_by_rule(self, is_order_by_rule):
        """
        Sets the is_order_by_rule of this RuleTypeConfig.
        Specifies whether it is ordered by rule.


        :param is_order_by_rule: The is_order_by_rule of this RuleTypeConfig.
        :type: bool
        """
        self._is_order_by_rule = is_order_by_rule

    @property
    def projection_rules(self):
        """
        Gets the projection_rules of this RuleTypeConfig.
        The projection rules.


        :return: The projection_rules of this RuleTypeConfig.
        :rtype: list[oci.data_integration.models.ProjectionRule]
        """
        return self._projection_rules

    @projection_rules.setter
    def projection_rules(self, projection_rules):
        """
        Sets the projection_rules of this RuleTypeConfig.
        The projection rules.


        :param projection_rules: The projection_rules of this RuleTypeConfig.
        :type: list[oci.data_integration.models.ProjectionRule]
        """
        self._projection_rules = projection_rules

    @property
    def config_values(self):
        """
        Gets the config_values of this RuleTypeConfig.

        :return: The config_values of this RuleTypeConfig.
        :rtype: oci.data_integration.models.ConfigValues
        """
        return self._config_values

    @config_values.setter
    def config_values(self, config_values):
        """
        Sets the config_values of this RuleTypeConfig.

        :param config_values: The config_values of this RuleTypeConfig.
        :type: oci.data_integration.models.ConfigValues
        """
        self._config_values = config_values

    @property
    def object_status(self):
        """
        Gets the object_status of this RuleTypeConfig.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this RuleTypeConfig.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this RuleTypeConfig.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this RuleTypeConfig.
        :type: int
        """
        self._object_status = object_status

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .abstract_write_attribute import AbstractWriteAttribute
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ObjectStorageWriteAttributes(AbstractWriteAttribute):
    """
    Properties to configure writing to Object Storage.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ObjectStorageWriteAttributes object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.ObjectStorageWriteAttributes.model_type` attribute
        of this class is ``OBJECT_STORAGE_WRITE_ATTRIBUTE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this ObjectStorageWriteAttributes.
            Allowed values for this property are: "ORACLEWRITEATTRIBUTE", "ORACLEATPWRITEATTRIBUTE", "ORACLEADWCWRITEATTRIBUTE", "OBJECTSTORAGEWRITEATTRIBUTE", "ORACLE_WRITE_ATTRIBUTE", "ORACLE_ATP_WRITE_ATTRIBUTE", "ORACLE_ADWC_WRITE_ATTRIBUTE", "OBJECT_STORAGE_WRITE_ATTRIBUTE"
        :type model_type: str

        :param write_to_single_file:
            The value to assign to the write_to_single_file property of this ObjectStorageWriteAttributes.
        :type write_to_single_file: bool

        """
        self.swagger_types = {
            'model_type': 'str',
            'write_to_single_file': 'bool'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'write_to_single_file': 'writeToSingleFile'
        }

        self._model_type = None
        self._write_to_single_file = None
        self._model_type = 'OBJECT_STORAGE_WRITE_ATTRIBUTE'

    @property
    def write_to_single_file(self):
        """
        Gets the write_to_single_file of this ObjectStorageWriteAttributes.
        Specifies whether to write output to single-file or not.


        :return: The write_to_single_file of this ObjectStorageWriteAttributes.
        :rtype: bool
        """
        return self._write_to_single_file

    @write_to_single_file.setter
    def write_to_single_file(self, write_to_single_file):
        """
        Sets the write_to_single_file of this ObjectStorageWriteAttributes.
        Specifies whether to write output to single-file or not.


        :param write_to_single_file: The write_to_single_file of this ObjectStorageWriteAttributes.
        :type: bool
        """
        self._write_to_single_file = write_to_single_file

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
